import { BaseResource, CloudError, AzureServiceClientOptions } from "@azure/ms-rest-azure-js";
import * as msRest from "@azure/ms-rest-js";
export { BaseResource, CloudError };
/**
 * Classic Administrators
 */
export interface ClassicAdministrator {
    /**
     * The ID of the administrator.
     */
    id?: string;
    /**
     * The name of the administrator.
     */
    name?: string;
    /**
     * The type of the administrator.
     */
    type?: string;
    /**
     * The email address of the administrator.
     */
    emailAddress?: string;
    /**
     * The role of the administrator.
     */
    role?: string;
}
/**
 * Operation
 */
export interface ProviderOperation {
    /**
     * The operation name.
     */
    name?: string;
    /**
     * The operation display name.
     */
    displayName?: string;
    /**
     * The operation description.
     */
    description?: string;
    /**
     * The operation origin.
     */
    origin?: string;
    /**
     * The operation properties.
     */
    properties?: any;
    /**
     * The dataAction flag to specify the operation type.
     */
    isDataAction?: boolean;
}
/**
 * Resource Type
 */
export interface ResourceType {
    /**
     * The resource type name.
     */
    name?: string;
    /**
     * The resource type display name.
     */
    displayName?: string;
    /**
     * The resource type operations.
     */
    operations?: ProviderOperation[];
}
/**
 * Provider Operations metadata
 */
export interface ProviderOperationsMetadata {
    /**
     * The provider id.
     */
    id?: string;
    /**
     * The provider name.
     */
    name?: string;
    /**
     * The provider type.
     */
    type?: string;
    /**
     * The provider display name.
     */
    displayName?: string;
    /**
     * The provider resource types
     */
    resourceTypes?: ResourceType[];
    /**
     * The provider operations.
     */
    operations?: ProviderOperation[];
}
/**
 * Role Assignments filter
 */
export interface RoleAssignmentFilter {
    /**
     * Returns role assignment of the specific principal.
     */
    principalId?: string;
    /**
     * The Delegation flag for the role assignment
     */
    canDelegate?: boolean;
}
/**
 * Role Assignments
 */
export interface RoleAssignment {
    /**
     * The role assignment ID.
     * **NOTE: This property will not be serialized. It can only be populated by the server.**
     */
    readonly id?: string;
    /**
     * The role assignment name.
     * **NOTE: This property will not be serialized. It can only be populated by the server.**
     */
    readonly name?: string;
    /**
     * The role assignment type.
     * **NOTE: This property will not be serialized. It can only be populated by the server.**
     */
    readonly type?: string;
    /**
     * The role assignment scope.
     */
    scope?: string;
    /**
     * The role definition ID.
     */
    roleDefinitionId?: string;
    /**
     * The principal ID.
     */
    principalId?: string;
    /**
     * The principal type of the assigned principal ID. Possible values include: 'User', 'Group',
     * 'ServicePrincipal', 'Unknown', 'DirectoryRoleTemplate', 'ForeignGroup', 'Application', 'MSI',
     * 'DirectoryObjectOrGroup', 'Everyone'
     */
    principalType?: PrincipalType;
    /**
     * The Delegation flag for the role assignment
     */
    canDelegate?: boolean;
}
/**
 * Role assignment create parameters.
 */
export interface RoleAssignmentCreateParameters {
    /**
     * The role definition ID used in the role assignment.
     */
    roleDefinitionId: string;
    /**
     * The principal ID assigned to the role. This maps to the ID inside the Active Directory. It can
     * point to a user, service principal, or security group.
     */
    principalId: string;
    /**
     * The principal type of the assigned principal ID. Possible values include: 'User', 'Group',
     * 'ServicePrincipal', 'Unknown', 'DirectoryRoleTemplate', 'ForeignGroup', 'Application', 'MSI',
     * 'DirectoryObjectOrGroup', 'Everyone'
     */
    principalType?: PrincipalType;
    /**
     * The delegation flag used for creating a role assignment
     */
    canDelegate?: boolean;
}
/**
 * Role Definitions filter
 */
export interface RoleDefinitionFilter {
    /**
     * Returns role definition with the specific name.
     */
    roleName?: string;
    /**
     * Returns role definition with the specific type.
     */
    type?: string;
}
/**
 * Role definition permissions.
 */
export interface Permission {
    /**
     * Allowed actions.
     */
    actions?: string[];
    /**
     * Denied actions.
     */
    notActions?: string[];
    /**
     * Allowed Data actions.
     */
    dataActions?: string[];
    /**
     * Denied Data actions.
     */
    notDataActions?: string[];
}
/**
 * Role definition.
 */
export interface RoleDefinition {
    /**
     * The role definition ID.
     * **NOTE: This property will not be serialized. It can only be populated by the server.**
     */
    readonly id?: string;
    /**
     * The role definition name.
     * **NOTE: This property will not be serialized. It can only be populated by the server.**
     */
    readonly name?: string;
    /**
     * The role definition type.
     * **NOTE: This property will not be serialized. It can only be populated by the server.**
     */
    readonly type?: string;
    /**
     * The role name.
     */
    roleName?: string;
    /**
     * The role definition description.
     */
    description?: string;
    /**
     * The role type.
     */
    roleType?: string;
    /**
     * Role definition permissions.
     */
    permissions?: Permission[];
    /**
     * Role definition assignable scopes.
     */
    assignableScopes?: string[];
}
/**
 * Deny Assignments filter
 */
export interface DenyAssignmentFilter {
    /**
     * Return deny assignment with specified name.
     */
    denyAssignmentName?: string;
    /**
     * Return all deny assignments where the specified principal is listed in the principals list of
     * deny assignments.
     */
    principalId?: string;
    /**
     * Return all deny assignments where the specified principal is listed either in the principals
     * list or exclude principals list of deny assignments.
     */
    gdprExportPrincipalId?: string;
}
/**
 * Deny assignment permissions.
 */
export interface DenyAssignmentPermission {
    /**
     * Actions to which the deny assignment does not grant access.
     */
    actions?: string[];
    /**
     * Actions to exclude from that the deny assignment does not grant access.
     */
    notActions?: string[];
    /**
     * Data actions to which the deny assignment does not grant access.
     */
    dataActions?: string[];
    /**
     * Data actions to exclude from that the deny assignment does not grant access.
     */
    notDataActions?: string[];
}
/**
 * Deny assignment principal.
 */
export interface Principal {
    /**
     * Object ID of the Azure AD principal (user, group, or service principal) to which the deny
     * assignment applies. An empty guid '00000000-0000-0000-0000-000000000000' as principal id and
     * principal type as 'Everyone' represents all users, groups and service principals.
     * **NOTE: This property will not be serialized. It can only be populated by the server.**
     */
    readonly id?: string;
    /**
     * Type of object represented by principal id (user, group, or service principal). An empty guid
     * '00000000-0000-0000-0000-000000000000' as principal id and principal type as 'Everyone'
     * represents all users, groups and service principals.
     * **NOTE: This property will not be serialized. It can only be populated by the server.**
     */
    readonly type?: string;
}
/**
 * Deny Assignment
 */
export interface DenyAssignment {
    /**
     * The deny assignment ID.
     * **NOTE: This property will not be serialized. It can only be populated by the server.**
     */
    readonly id?: string;
    /**
     * The deny assignment name.
     * **NOTE: This property will not be serialized. It can only be populated by the server.**
     */
    readonly name?: string;
    /**
     * The deny assignment type.
     * **NOTE: This property will not be serialized. It can only be populated by the server.**
     */
    readonly type?: string;
    /**
     * The display name of the deny assignment.
     */
    denyAssignmentName?: string;
    /**
     * The description of the deny assignment.
     */
    description?: string;
    /**
     * An array of permissions that are denied by the deny assignment.
     */
    permissions?: DenyAssignmentPermission[];
    /**
     * The deny assignment scope.
     */
    scope?: string;
    /**
     * Determines if the deny assignment applies to child scopes. Default value is false.
     */
    doNotApplyToChildScopes?: boolean;
    /**
     * Array of principals to which the deny assignment applies.
     */
    principals?: Principal[];
    /**
     * Array of principals to which the deny assignment does not apply.
     */
    excludePrincipals?: Principal[];
    /**
     * Specifies whether this deny assignment was created by Azure and cannot be edited or deleted.
     */
    isSystemProtected?: boolean;
}
/**
 * Optional Parameters.
 */
export interface ProviderOperationsMetadataGetOptionalParams extends msRest.RequestOptionsBase {
    /**
     * Specifies whether to expand the values. Default value: 'resourceTypes'.
     */
    expand?: string;
}
/**
 * Optional Parameters.
 */
export interface ProviderOperationsMetadataListOptionalParams extends msRest.RequestOptionsBase {
    /**
     * Specifies whether to expand the values. Default value: 'resourceTypes'.
     */
    expand?: string;
}
/**
 * Optional Parameters.
 */
export interface RoleAssignmentsListForResourceOptionalParams extends msRest.RequestOptionsBase {
    /**
     * The filter to apply on the operation. Use $filter=atScope() to return all role assignments at
     * or above the scope. Use $filter=principalId eq {id} to return all role assignments at, above
     * or below the scope for the specified principal.
     */
    filter?: string;
}
/**
 * Optional Parameters.
 */
export interface RoleAssignmentsListForResourceGroupOptionalParams extends msRest.RequestOptionsBase {
    /**
     * The filter to apply on the operation. Use $filter=atScope() to return all role assignments at
     * or above the scope. Use $filter=principalId eq {id} to return all role assignments at, above
     * or below the scope for the specified principal.
     */
    filter?: string;
}
/**
 * Optional Parameters.
 */
export interface RoleAssignmentsListOptionalParams extends msRest.RequestOptionsBase {
    /**
     * The filter to apply on the operation. Use $filter=atScope() to return all role assignments at
     * or above the scope. Use $filter=principalId eq {id} to return all role assignments at, above
     * or below the scope for the specified principal.
     */
    filter?: string;
}
/**
 * Optional Parameters.
 */
export interface RoleAssignmentsListForScopeOptionalParams extends msRest.RequestOptionsBase {
    /**
     * The filter to apply on the operation. Use $filter=atScope() to return all role assignments at
     * or above the scope. Use $filter=principalId eq {id} to return all role assignments at, above
     * or below the scope for the specified principal.
     */
    filter?: string;
}
/**
 * Optional Parameters.
 */
export interface RoleDefinitionsListOptionalParams extends msRest.RequestOptionsBase {
    /**
     * The filter to apply on the operation. Use atScopeAndBelow filter to search below the given
     * scope as well.
     */
    filter?: string;
}
/**
 * Optional Parameters.
 */
export interface DenyAssignmentsListForResourceOptionalParams extends msRest.RequestOptionsBase {
    /**
     * The filter to apply on the operation. Use $filter=atScope() to return all deny assignments at
     * or above the scope. Use $filter=denyAssignmentName eq '{name}' to search deny assignments by
     * name at specified scope. Use $filter=principalId eq '{id}' to return all deny assignments at,
     * above and below the scope for the specified principal. Use $filter=gdprExportPrincipalId eq
     * '{id}' to return all deny assignments at, above and below the scope for the specified
     * principal. This filter is different from the principalId filter as it returns not only those
     * deny assignments that contain the specified principal is the Principals list but also those
     * deny assignments that contain the specified principal is the ExcludePrincipals list.
     * Additionally, when gdprExportPrincipalId filter is used, only the deny assignment name and
     * description properties are returned.
     */
    filter?: string;
}
/**
 * Optional Parameters.
 */
export interface DenyAssignmentsListForResourceGroupOptionalParams extends msRest.RequestOptionsBase {
    /**
     * The filter to apply on the operation. Use $filter=atScope() to return all deny assignments at
     * or above the scope. Use $filter=denyAssignmentName eq '{name}' to search deny assignments by
     * name at specified scope. Use $filter=principalId eq '{id}' to return all deny assignments at,
     * above and below the scope for the specified principal. Use $filter=gdprExportPrincipalId eq
     * '{id}' to return all deny assignments at, above and below the scope for the specified
     * principal. This filter is different from the principalId filter as it returns not only those
     * deny assignments that contain the specified principal is the Principals list but also those
     * deny assignments that contain the specified principal is the ExcludePrincipals list.
     * Additionally, when gdprExportPrincipalId filter is used, only the deny assignment name and
     * description properties are returned.
     */
    filter?: string;
}
/**
 * Optional Parameters.
 */
export interface DenyAssignmentsListOptionalParams extends msRest.RequestOptionsBase {
    /**
     * The filter to apply on the operation. Use $filter=atScope() to return all deny assignments at
     * or above the scope. Use $filter=denyAssignmentName eq '{name}' to search deny assignments by
     * name at specified scope. Use $filter=principalId eq '{id}' to return all deny assignments at,
     * above and below the scope for the specified principal. Use $filter=gdprExportPrincipalId eq
     * '{id}' to return all deny assignments at, above and below the scope for the specified
     * principal. This filter is different from the principalId filter as it returns not only those
     * deny assignments that contain the specified principal is the Principals list but also those
     * deny assignments that contain the specified principal is the ExcludePrincipals list.
     * Additionally, when gdprExportPrincipalId filter is used, only the deny assignment name and
     * description properties are returned.
     */
    filter?: string;
}
/**
 * Optional Parameters.
 */
export interface DenyAssignmentsListForScopeOptionalParams extends msRest.RequestOptionsBase {
    /**
     * The filter to apply on the operation. Use $filter=atScope() to return all deny assignments at
     * or above the scope. Use $filter=denyAssignmentName eq '{name}' to search deny assignments by
     * name at specified scope. Use $filter=principalId eq '{id}' to return all deny assignments at,
     * above and below the scope for the specified principal. Use $filter=gdprExportPrincipalId eq
     * '{id}' to return all deny assignments at, above and below the scope for the specified
     * principal. This filter is different from the principalId filter as it returns not only those
     * deny assignments that contain the specified principal is the Principals list but also those
     * deny assignments that contain the specified principal is the ExcludePrincipals list.
     * Additionally, when gdprExportPrincipalId filter is used, only the deny assignment name and
     * description properties are returned.
     */
    filter?: string;
}
/**
 * An interface representing AuthorizationManagementClientOptions.
 */
export interface AuthorizationManagementClientOptions extends AzureServiceClientOptions {
    baseUri?: string;
}
/**
 * @interface
 * ClassicAdministrator list result information.
 * @extends Array<ClassicAdministrator>
 */
export interface ClassicAdministratorListResult extends Array<ClassicAdministrator> {
    /**
     * The URL to use for getting the next set of results.
     */
    nextLink?: string;
}
/**
 * @interface
 * Provider operations metadata list
 * @extends Array<ProviderOperationsMetadata>
 */
export interface ProviderOperationsMetadataListResult extends Array<ProviderOperationsMetadata> {
    /**
     * The URL to use for getting the next set of results.
     */
    nextLink?: string;
}
/**
 * @interface
 * Role assignment list operation result.
 * @extends Array<RoleAssignment>
 */
export interface RoleAssignmentListResult extends Array<RoleAssignment> {
    /**
     * The URL to use for getting the next set of results.
     */
    nextLink?: string;
}
/**
 * @interface
 * Permissions information.
 * @extends Array<Permission>
 */
export interface PermissionGetResult extends Array<Permission> {
    /**
     * The URL to use for getting the next set of results.
     */
    nextLink?: string;
}
/**
 * @interface
 * Role definition list operation result.
 * @extends Array<RoleDefinition>
 */
export interface RoleDefinitionListResult extends Array<RoleDefinition> {
    /**
     * The URL to use for getting the next set of results.
     */
    nextLink?: string;
}
/**
 * @interface
 * Deny assignment list operation result.
 * @extends Array<DenyAssignment>
 */
export interface DenyAssignmentListResult extends Array<DenyAssignment> {
    /**
     * The URL to use for getting the next set of results.
     */
    nextLink?: string;
}
/**
 * Defines values for PrincipalType.
 * Possible values include: 'User', 'Group', 'ServicePrincipal', 'Unknown',
 * 'DirectoryRoleTemplate', 'ForeignGroup', 'Application', 'MSI', 'DirectoryObjectOrGroup',
 * 'Everyone'
 * @readonly
 * @enum {string}
 */
export declare type PrincipalType = 'User' | 'Group' | 'ServicePrincipal' | 'Unknown' | 'DirectoryRoleTemplate' | 'ForeignGroup' | 'Application' | 'MSI' | 'DirectoryObjectOrGroup' | 'Everyone';
/**
 * Contains response data for the list operation.
 */
export declare type ClassicAdministratorsListResponse = ClassicAdministratorListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ClassicAdministratorListResult;
    };
};
/**
 * Contains response data for the listNext operation.
 */
export declare type ClassicAdministratorsListNextResponse = ClassicAdministratorListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ClassicAdministratorListResult;
    };
};
/**
 * Contains response data for the get operation.
 */
export declare type ProviderOperationsMetadataGetResponse = ProviderOperationsMetadata & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ProviderOperationsMetadata;
    };
};
/**
 * Contains response data for the list operation.
 */
export declare type ProviderOperationsMetadataListResponse = ProviderOperationsMetadataListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ProviderOperationsMetadataListResult;
    };
};
/**
 * Contains response data for the listNext operation.
 */
export declare type ProviderOperationsMetadataListNextResponse = ProviderOperationsMetadataListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: ProviderOperationsMetadataListResult;
    };
};
/**
 * Contains response data for the listForResource operation.
 */
export declare type RoleAssignmentsListForResourceResponse = RoleAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignmentListResult;
    };
};
/**
 * Contains response data for the listForResourceGroup operation.
 */
export declare type RoleAssignmentsListForResourceGroupResponse = RoleAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignmentListResult;
    };
};
/**
 * Contains response data for the deleteMethod operation.
 */
export declare type RoleAssignmentsDeleteMethodResponse = RoleAssignment & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignment;
    };
};
/**
 * Contains response data for the create operation.
 */
export declare type RoleAssignmentsCreateResponse = RoleAssignment & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignment;
    };
};
/**
 * Contains response data for the get operation.
 */
export declare type RoleAssignmentsGetResponse = RoleAssignment & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignment;
    };
};
/**
 * Contains response data for the deleteById operation.
 */
export declare type RoleAssignmentsDeleteByIdResponse = RoleAssignment & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignment;
    };
};
/**
 * Contains response data for the createById operation.
 */
export declare type RoleAssignmentsCreateByIdResponse = RoleAssignment & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignment;
    };
};
/**
 * Contains response data for the getById operation.
 */
export declare type RoleAssignmentsGetByIdResponse = RoleAssignment & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignment;
    };
};
/**
 * Contains response data for the list operation.
 */
export declare type RoleAssignmentsListResponse = RoleAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignmentListResult;
    };
};
/**
 * Contains response data for the listForScope operation.
 */
export declare type RoleAssignmentsListForScopeResponse = RoleAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignmentListResult;
    };
};
/**
 * Contains response data for the listForResourceNext operation.
 */
export declare type RoleAssignmentsListForResourceNextResponse = RoleAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignmentListResult;
    };
};
/**
 * Contains response data for the listForResourceGroupNext operation.
 */
export declare type RoleAssignmentsListForResourceGroupNextResponse = RoleAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignmentListResult;
    };
};
/**
 * Contains response data for the listNext operation.
 */
export declare type RoleAssignmentsListNextResponse = RoleAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignmentListResult;
    };
};
/**
 * Contains response data for the listForScopeNext operation.
 */
export declare type RoleAssignmentsListForScopeNextResponse = RoleAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleAssignmentListResult;
    };
};
/**
 * Contains response data for the listForResourceGroup operation.
 */
export declare type PermissionsListForResourceGroupResponse = PermissionGetResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PermissionGetResult;
    };
};
/**
 * Contains response data for the listForResource operation.
 */
export declare type PermissionsListForResourceResponse = PermissionGetResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PermissionGetResult;
    };
};
/**
 * Contains response data for the listForResourceGroupNext operation.
 */
export declare type PermissionsListForResourceGroupNextResponse = PermissionGetResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PermissionGetResult;
    };
};
/**
 * Contains response data for the listForResourceNext operation.
 */
export declare type PermissionsListForResourceNextResponse = PermissionGetResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: PermissionGetResult;
    };
};
/**
 * Contains response data for the deleteMethod operation.
 */
export declare type RoleDefinitionsDeleteMethodResponse = RoleDefinition & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleDefinition;
    };
};
/**
 * Contains response data for the get operation.
 */
export declare type RoleDefinitionsGetResponse = RoleDefinition & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleDefinition;
    };
};
/**
 * Contains response data for the createOrUpdate operation.
 */
export declare type RoleDefinitionsCreateOrUpdateResponse = RoleDefinition & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleDefinition;
    };
};
/**
 * Contains response data for the list operation.
 */
export declare type RoleDefinitionsListResponse = RoleDefinitionListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleDefinitionListResult;
    };
};
/**
 * Contains response data for the getById operation.
 */
export declare type RoleDefinitionsGetByIdResponse = RoleDefinition & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleDefinition;
    };
};
/**
 * Contains response data for the listNext operation.
 */
export declare type RoleDefinitionsListNextResponse = RoleDefinitionListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: RoleDefinitionListResult;
    };
};
/**
 * Contains response data for the listForResource operation.
 */
export declare type DenyAssignmentsListForResourceResponse = DenyAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: DenyAssignmentListResult;
    };
};
/**
 * Contains response data for the listForResourceGroup operation.
 */
export declare type DenyAssignmentsListForResourceGroupResponse = DenyAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: DenyAssignmentListResult;
    };
};
/**
 * Contains response data for the list operation.
 */
export declare type DenyAssignmentsListResponse = DenyAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: DenyAssignmentListResult;
    };
};
/**
 * Contains response data for the get operation.
 */
export declare type DenyAssignmentsGetResponse = DenyAssignment & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: DenyAssignment;
    };
};
/**
 * Contains response data for the getById operation.
 */
export declare type DenyAssignmentsGetByIdResponse = DenyAssignment & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: DenyAssignment;
    };
};
/**
 * Contains response data for the listForScope operation.
 */
export declare type DenyAssignmentsListForScopeResponse = DenyAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: DenyAssignmentListResult;
    };
};
/**
 * Contains response data for the listForResourceNext operation.
 */
export declare type DenyAssignmentsListForResourceNextResponse = DenyAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: DenyAssignmentListResult;
    };
};
/**
 * Contains response data for the listForResourceGroupNext operation.
 */
export declare type DenyAssignmentsListForResourceGroupNextResponse = DenyAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: DenyAssignmentListResult;
    };
};
/**
 * Contains response data for the listNext operation.
 */
export declare type DenyAssignmentsListNextResponse = DenyAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: DenyAssignmentListResult;
    };
};
/**
 * Contains response data for the listForScopeNext operation.
 */
export declare type DenyAssignmentsListForScopeNextResponse = DenyAssignmentListResult & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: DenyAssignmentListResult;
    };
};
//# sourceMappingURL=index.d.ts.map