import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { AuthorizationManagementClientContext } from "../authorizationManagementClientContext";
/** Class representing a DenyAssignments. */
export declare class DenyAssignments {
    private readonly client;
    /**
     * Create a DenyAssignments.
     * @param {AuthorizationManagementClientContext} client Reference to the service client.
     */
    constructor(client: AuthorizationManagementClientContext);
    /**
     * Gets deny assignments for a resource.
     * @param resourceGroupName The name of the resource group.
     * @param resourceProviderNamespace The namespace of the resource provider.
     * @param parentResourcePath The parent resource identity.
     * @param resourceType The resource type of the resource.
     * @param resourceName The name of the resource to get deny assignments for.
     * @param [options] The optional parameters
     * @returns Promise<Models.DenyAssignmentsListForResourceResponse>
     */
    listForResource(resourceGroupName: string, resourceProviderNamespace: string, parentResourcePath: string, resourceType: string, resourceName: string, options?: Models.DenyAssignmentsListForResourceOptionalParams): Promise<Models.DenyAssignmentsListForResourceResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param resourceProviderNamespace The namespace of the resource provider.
     * @param parentResourcePath The parent resource identity.
     * @param resourceType The resource type of the resource.
     * @param resourceName The name of the resource to get deny assignments for.
     * @param callback The callback
     */
    listForResource(resourceGroupName: string, resourceProviderNamespace: string, parentResourcePath: string, resourceType: string, resourceName: string, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param resourceProviderNamespace The namespace of the resource provider.
     * @param parentResourcePath The parent resource identity.
     * @param resourceType The resource type of the resource.
     * @param resourceName The name of the resource to get deny assignments for.
     * @param options The optional parameters
     * @param callback The callback
     */
    listForResource(resourceGroupName: string, resourceProviderNamespace: string, parentResourcePath: string, resourceType: string, resourceName: string, options: Models.DenyAssignmentsListForResourceOptionalParams, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * Gets deny assignments for a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param [options] The optional parameters
     * @returns Promise<Models.DenyAssignmentsListForResourceGroupResponse>
     */
    listForResourceGroup(resourceGroupName: string, options?: Models.DenyAssignmentsListForResourceGroupOptionalParams): Promise<Models.DenyAssignmentsListForResourceGroupResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param callback The callback
     */
    listForResourceGroup(resourceGroupName: string, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param options The optional parameters
     * @param callback The callback
     */
    listForResourceGroup(resourceGroupName: string, options: Models.DenyAssignmentsListForResourceGroupOptionalParams, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * Gets all deny assignments for the subscription.
     * @param [options] The optional parameters
     * @returns Promise<Models.DenyAssignmentsListResponse>
     */
    list(options?: Models.DenyAssignmentsListOptionalParams): Promise<Models.DenyAssignmentsListResponse>;
    /**
     * @param callback The callback
     */
    list(callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    list(options: Models.DenyAssignmentsListOptionalParams, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * Get the specified deny assignment.
     * @param scope The scope of the deny assignment.
     * @param denyAssignmentId The ID of the deny assignment to get.
     * @param [options] The optional parameters
     * @returns Promise<Models.DenyAssignmentsGetResponse>
     */
    get(scope: string, denyAssignmentId: string, options?: msRest.RequestOptionsBase): Promise<Models.DenyAssignmentsGetResponse>;
    /**
     * @param scope The scope of the deny assignment.
     * @param denyAssignmentId The ID of the deny assignment to get.
     * @param callback The callback
     */
    get(scope: string, denyAssignmentId: string, callback: msRest.ServiceCallback<Models.DenyAssignment>): void;
    /**
     * @param scope The scope of the deny assignment.
     * @param denyAssignmentId The ID of the deny assignment to get.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(scope: string, denyAssignmentId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DenyAssignment>): void;
    /**
     * Gets a deny assignment by ID.
     * @param denyAssignmentId The fully qualified deny assignment ID. For example, use the format,
     * /subscriptions/{guid}/providers/Microsoft.Authorization/denyAssignments/{denyAssignmentId} for
     * subscription level deny assignments, or
     * /providers/Microsoft.Authorization/denyAssignments/{denyAssignmentId} for tenant level deny
     * assignments.
     * @param [options] The optional parameters
     * @returns Promise<Models.DenyAssignmentsGetByIdResponse>
     */
    getById(denyAssignmentId: string, options?: msRest.RequestOptionsBase): Promise<Models.DenyAssignmentsGetByIdResponse>;
    /**
     * @param denyAssignmentId The fully qualified deny assignment ID. For example, use the format,
     * /subscriptions/{guid}/providers/Microsoft.Authorization/denyAssignments/{denyAssignmentId} for
     * subscription level deny assignments, or
     * /providers/Microsoft.Authorization/denyAssignments/{denyAssignmentId} for tenant level deny
     * assignments.
     * @param callback The callback
     */
    getById(denyAssignmentId: string, callback: msRest.ServiceCallback<Models.DenyAssignment>): void;
    /**
     * @param denyAssignmentId The fully qualified deny assignment ID. For example, use the format,
     * /subscriptions/{guid}/providers/Microsoft.Authorization/denyAssignments/{denyAssignmentId} for
     * subscription level deny assignments, or
     * /providers/Microsoft.Authorization/denyAssignments/{denyAssignmentId} for tenant level deny
     * assignments.
     * @param options The optional parameters
     * @param callback The callback
     */
    getById(denyAssignmentId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DenyAssignment>): void;
    /**
     * Gets deny assignments for a scope.
     * @param scope The scope of the deny assignments.
     * @param [options] The optional parameters
     * @returns Promise<Models.DenyAssignmentsListForScopeResponse>
     */
    listForScope(scope: string, options?: Models.DenyAssignmentsListForScopeOptionalParams): Promise<Models.DenyAssignmentsListForScopeResponse>;
    /**
     * @param scope The scope of the deny assignments.
     * @param callback The callback
     */
    listForScope(scope: string, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * @param scope The scope of the deny assignments.
     * @param options The optional parameters
     * @param callback The callback
     */
    listForScope(scope: string, options: Models.DenyAssignmentsListForScopeOptionalParams, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * Gets deny assignments for a resource.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DenyAssignmentsListForResourceNextResponse>
     */
    listForResourceNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.DenyAssignmentsListForResourceNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listForResourceNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listForResourceNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * Gets deny assignments for a resource group.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DenyAssignmentsListForResourceGroupNextResponse>
     */
    listForResourceGroupNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.DenyAssignmentsListForResourceGroupNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listForResourceGroupNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listForResourceGroupNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * Gets all deny assignments for the subscription.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DenyAssignmentsListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.DenyAssignmentsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * Gets deny assignments for a scope.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DenyAssignmentsListForScopeNextResponse>
     */
    listForScopeNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.DenyAssignmentsListForScopeNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listForScopeNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listForScopeNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DenyAssignmentListResult>): void;
}
//# sourceMappingURL=denyAssignments.d.ts.map