import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { AuthorizationManagementClientContext } from "../authorizationManagementClientContext";
/** Class representing a RoleAssignments. */
export declare class RoleAssignments {
    private readonly client;
    /**
     * Create a RoleAssignments.
     * @param {AuthorizationManagementClientContext} client Reference to the service client.
     */
    constructor(client: AuthorizationManagementClientContext);
    /**
     * Gets role assignments for a resource.
     * @param resourceGroupName The name of the resource group.
     * @param resourceProviderNamespace The namespace of the resource provider.
     * @param parentResourcePath The parent resource identity.
     * @param resourceType The resource type of the resource.
     * @param resourceName The name of the resource to get role assignments for.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsListForResourceResponse>
     */
    listForResource(resourceGroupName: string, resourceProviderNamespace: string, parentResourcePath: string, resourceType: string, resourceName: string, options?: Models.RoleAssignmentsListForResourceOptionalParams): Promise<Models.RoleAssignmentsListForResourceResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param resourceProviderNamespace The namespace of the resource provider.
     * @param parentResourcePath The parent resource identity.
     * @param resourceType The resource type of the resource.
     * @param resourceName The name of the resource to get role assignments for.
     * @param callback The callback
     */
    listForResource(resourceGroupName: string, resourceProviderNamespace: string, parentResourcePath: string, resourceType: string, resourceName: string, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param resourceProviderNamespace The namespace of the resource provider.
     * @param parentResourcePath The parent resource identity.
     * @param resourceType The resource type of the resource.
     * @param resourceName The name of the resource to get role assignments for.
     * @param options The optional parameters
     * @param callback The callback
     */
    listForResource(resourceGroupName: string, resourceProviderNamespace: string, parentResourcePath: string, resourceType: string, resourceName: string, options: Models.RoleAssignmentsListForResourceOptionalParams, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * Gets role assignments for a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsListForResourceGroupResponse>
     */
    listForResourceGroup(resourceGroupName: string, options?: Models.RoleAssignmentsListForResourceGroupOptionalParams): Promise<Models.RoleAssignmentsListForResourceGroupResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param callback The callback
     */
    listForResourceGroup(resourceGroupName: string, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param options The optional parameters
     * @param callback The callback
     */
    listForResourceGroup(resourceGroupName: string, options: Models.RoleAssignmentsListForResourceGroupOptionalParams, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * Deletes a role assignment.
     * @param scope The scope of the role assignment to delete.
     * @param roleAssignmentName The name of the role assignment to delete.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsDeleteMethodResponse>
     */
    deleteMethod(scope: string, roleAssignmentName: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleAssignmentsDeleteMethodResponse>;
    /**
     * @param scope The scope of the role assignment to delete.
     * @param roleAssignmentName The name of the role assignment to delete.
     * @param callback The callback
     */
    deleteMethod(scope: string, roleAssignmentName: string, callback: msRest.ServiceCallback<Models.RoleAssignment>): void;
    /**
     * @param scope The scope of the role assignment to delete.
     * @param roleAssignmentName The name of the role assignment to delete.
     * @param options The optional parameters
     * @param callback The callback
     */
    deleteMethod(scope: string, roleAssignmentName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleAssignment>): void;
    /**
     * Creates a role assignment.
     * @param scope The scope of the role assignment to create. The scope can be any REST resource
     * instance. For example, use '/subscriptions/{subscription-id}/' for a subscription,
     * '/subscriptions/{subscription-id}/resourceGroups/{resource-group-name}' for a resource group,
     * and
     * '/subscriptions/{subscription-id}/resourceGroups/{resource-group-name}/providers/{resource-provider}/{resource-type}/{resource-name}'
     * for a resource.
     * @param roleAssignmentName The name of the role assignment to create. It can be any valid GUID.
     * @param parameters Parameters for the role assignment.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsCreateResponse>
     */
    create(scope: string, roleAssignmentName: string, parameters: Models.RoleAssignmentCreateParameters, options?: msRest.RequestOptionsBase): Promise<Models.RoleAssignmentsCreateResponse>;
    /**
     * @param scope The scope of the role assignment to create. The scope can be any REST resource
     * instance. For example, use '/subscriptions/{subscription-id}/' for a subscription,
     * '/subscriptions/{subscription-id}/resourceGroups/{resource-group-name}' for a resource group,
     * and
     * '/subscriptions/{subscription-id}/resourceGroups/{resource-group-name}/providers/{resource-provider}/{resource-type}/{resource-name}'
     * for a resource.
     * @param roleAssignmentName The name of the role assignment to create. It can be any valid GUID.
     * @param parameters Parameters for the role assignment.
     * @param callback The callback
     */
    create(scope: string, roleAssignmentName: string, parameters: Models.RoleAssignmentCreateParameters, callback: msRest.ServiceCallback<Models.RoleAssignment>): void;
    /**
     * @param scope The scope of the role assignment to create. The scope can be any REST resource
     * instance. For example, use '/subscriptions/{subscription-id}/' for a subscription,
     * '/subscriptions/{subscription-id}/resourceGroups/{resource-group-name}' for a resource group,
     * and
     * '/subscriptions/{subscription-id}/resourceGroups/{resource-group-name}/providers/{resource-provider}/{resource-type}/{resource-name}'
     * for a resource.
     * @param roleAssignmentName The name of the role assignment to create. It can be any valid GUID.
     * @param parameters Parameters for the role assignment.
     * @param options The optional parameters
     * @param callback The callback
     */
    create(scope: string, roleAssignmentName: string, parameters: Models.RoleAssignmentCreateParameters, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleAssignment>): void;
    /**
     * Get the specified role assignment.
     * @param scope The scope of the role assignment.
     * @param roleAssignmentName The name of the role assignment to get.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsGetResponse>
     */
    get(scope: string, roleAssignmentName: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleAssignmentsGetResponse>;
    /**
     * @param scope The scope of the role assignment.
     * @param roleAssignmentName The name of the role assignment to get.
     * @param callback The callback
     */
    get(scope: string, roleAssignmentName: string, callback: msRest.ServiceCallback<Models.RoleAssignment>): void;
    /**
     * @param scope The scope of the role assignment.
     * @param roleAssignmentName The name of the role assignment to get.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(scope: string, roleAssignmentName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleAssignment>): void;
    /**
     * Deletes a role assignment.
     * @param roleId The ID of the role assignment to delete.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsDeleteByIdResponse>
     */
    deleteById(roleId: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleAssignmentsDeleteByIdResponse>;
    /**
     * @param roleId The ID of the role assignment to delete.
     * @param callback The callback
     */
    deleteById(roleId: string, callback: msRest.ServiceCallback<Models.RoleAssignment>): void;
    /**
     * @param roleId The ID of the role assignment to delete.
     * @param options The optional parameters
     * @param callback The callback
     */
    deleteById(roleId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleAssignment>): void;
    /**
     * Creates a role assignment by ID.
     * @param roleId The ID of the role assignment to create.
     * @param parameters Parameters for the role assignment.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsCreateByIdResponse>
     */
    createById(roleId: string, parameters: Models.RoleAssignmentCreateParameters, options?: msRest.RequestOptionsBase): Promise<Models.RoleAssignmentsCreateByIdResponse>;
    /**
     * @param roleId The ID of the role assignment to create.
     * @param parameters Parameters for the role assignment.
     * @param callback The callback
     */
    createById(roleId: string, parameters: Models.RoleAssignmentCreateParameters, callback: msRest.ServiceCallback<Models.RoleAssignment>): void;
    /**
     * @param roleId The ID of the role assignment to create.
     * @param parameters Parameters for the role assignment.
     * @param options The optional parameters
     * @param callback The callback
     */
    createById(roleId: string, parameters: Models.RoleAssignmentCreateParameters, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleAssignment>): void;
    /**
     * Gets a role assignment by ID.
     * @param roleId The ID of the role assignment to get.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsGetByIdResponse>
     */
    getById(roleId: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleAssignmentsGetByIdResponse>;
    /**
     * @param roleId The ID of the role assignment to get.
     * @param callback The callback
     */
    getById(roleId: string, callback: msRest.ServiceCallback<Models.RoleAssignment>): void;
    /**
     * @param roleId The ID of the role assignment to get.
     * @param options The optional parameters
     * @param callback The callback
     */
    getById(roleId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleAssignment>): void;
    /**
     * Gets all role assignments for the subscription.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsListResponse>
     */
    list(options?: Models.RoleAssignmentsListOptionalParams): Promise<Models.RoleAssignmentsListResponse>;
    /**
     * @param callback The callback
     */
    list(callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    list(options: Models.RoleAssignmentsListOptionalParams, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * Gets role assignments for a scope.
     * @param scope The scope of the role assignments.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsListForScopeResponse>
     */
    listForScope(scope: string, options?: Models.RoleAssignmentsListForScopeOptionalParams): Promise<Models.RoleAssignmentsListForScopeResponse>;
    /**
     * @param scope The scope of the role assignments.
     * @param callback The callback
     */
    listForScope(scope: string, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * @param scope The scope of the role assignments.
     * @param options The optional parameters
     * @param callback The callback
     */
    listForScope(scope: string, options: Models.RoleAssignmentsListForScopeOptionalParams, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * Gets role assignments for a resource.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsListForResourceNextResponse>
     */
    listForResourceNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleAssignmentsListForResourceNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listForResourceNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listForResourceNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * Gets role assignments for a resource group.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsListForResourceGroupNextResponse>
     */
    listForResourceGroupNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleAssignmentsListForResourceGroupNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listForResourceGroupNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listForResourceGroupNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * Gets all role assignments for the subscription.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleAssignmentsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * Gets role assignments for a scope.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleAssignmentsListForScopeNextResponse>
     */
    listForScopeNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleAssignmentsListForScopeNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listForScopeNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listForScopeNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleAssignmentListResult>): void;
}
//# sourceMappingURL=roleAssignments.d.ts.map