/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/roleAssignmentsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a RoleAssignments. */
var RoleAssignments = /** @class */ (function () {
    /**
     * Create a RoleAssignments.
     * @param {AuthorizationManagementClientContext} client Reference to the service client.
     */
    function RoleAssignments(client) {
        this.client = client;
    }
    RoleAssignments.prototype.listForResource = function (resourceGroupName, resourceProviderNamespace, parentResourcePath, resourceType, resourceName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            resourceProviderNamespace: resourceProviderNamespace,
            parentResourcePath: parentResourcePath,
            resourceType: resourceType,
            resourceName: resourceName,
            options: options
        }, listForResourceOperationSpec, callback);
    };
    RoleAssignments.prototype.listForResourceGroup = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listForResourceGroupOperationSpec, callback);
    };
    RoleAssignments.prototype.deleteMethod = function (scope, roleAssignmentName, options, callback) {
        return this.client.sendOperationRequest({
            scope: scope,
            roleAssignmentName: roleAssignmentName,
            options: options
        }, deleteMethodOperationSpec, callback);
    };
    RoleAssignments.prototype.create = function (scope, roleAssignmentName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            scope: scope,
            roleAssignmentName: roleAssignmentName,
            parameters: parameters,
            options: options
        }, createOperationSpec, callback);
    };
    RoleAssignments.prototype.get = function (scope, roleAssignmentName, options, callback) {
        return this.client.sendOperationRequest({
            scope: scope,
            roleAssignmentName: roleAssignmentName,
            options: options
        }, getOperationSpec, callback);
    };
    RoleAssignments.prototype.deleteById = function (roleId, options, callback) {
        return this.client.sendOperationRequest({
            roleId: roleId,
            options: options
        }, deleteByIdOperationSpec, callback);
    };
    RoleAssignments.prototype.createById = function (roleId, parameters, options, callback) {
        return this.client.sendOperationRequest({
            roleId: roleId,
            parameters: parameters,
            options: options
        }, createByIdOperationSpec, callback);
    };
    RoleAssignments.prototype.getById = function (roleId, options, callback) {
        return this.client.sendOperationRequest({
            roleId: roleId,
            options: options
        }, getByIdOperationSpec, callback);
    };
    RoleAssignments.prototype.list = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listOperationSpec, callback);
    };
    RoleAssignments.prototype.listForScope = function (scope, options, callback) {
        return this.client.sendOperationRequest({
            scope: scope,
            options: options
        }, listForScopeOperationSpec, callback);
    };
    RoleAssignments.prototype.listForResourceNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listForResourceNextOperationSpec, callback);
    };
    RoleAssignments.prototype.listForResourceGroupNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listForResourceGroupNextOperationSpec, callback);
    };
    RoleAssignments.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    RoleAssignments.prototype.listForScopeNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listForScopeNextOperationSpec, callback);
    };
    return RoleAssignments;
}());
export { RoleAssignments };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var listForResourceOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{parentResourcePath}/{resourceType}/{resourceName}/providers/Microsoft.Authorization/roleAssignments",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.resourceProviderNamespace,
        Parameters.parentResourcePath,
        Parameters.resourceType,
        Parameters.resourceName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.filter,
        Parameters.apiVersion3
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoleAssignmentListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listForResourceGroupOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Authorization/roleAssignments",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.filter,
        Parameters.apiVersion3
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoleAssignmentListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var deleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "{scope}/providers/Microsoft.Authorization/roleAssignments/{roleAssignmentName}",
    urlParameters: [
        Parameters.scope,
        Parameters.roleAssignmentName
    ],
    queryParameters: [
        Parameters.apiVersion3
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoleAssignment
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var createOperationSpec = {
    httpMethod: "PUT",
    path: "{scope}/providers/Microsoft.Authorization/roleAssignments/{roleAssignmentName}",
    urlParameters: [
        Parameters.scope,
        Parameters.roleAssignmentName
    ],
    queryParameters: [
        Parameters.apiVersion3
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.RoleAssignmentCreateParameters), { required: true })
    },
    responses: {
        201: {
            bodyMapper: Mappers.RoleAssignment
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getOperationSpec = {
    httpMethod: "GET",
    path: "{scope}/providers/Microsoft.Authorization/roleAssignments/{roleAssignmentName}",
    urlParameters: [
        Parameters.scope,
        Parameters.roleAssignmentName
    ],
    queryParameters: [
        Parameters.apiVersion3
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoleAssignment
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var deleteByIdOperationSpec = {
    httpMethod: "DELETE",
    path: "{roleId}",
    urlParameters: [
        Parameters.roleId
    ],
    queryParameters: [
        Parameters.apiVersion3
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoleAssignment
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var createByIdOperationSpec = {
    httpMethod: "PUT",
    path: "{roleId}",
    urlParameters: [
        Parameters.roleId
    ],
    queryParameters: [
        Parameters.apiVersion3
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.RoleAssignmentCreateParameters), { required: true })
    },
    responses: {
        201: {
            bodyMapper: Mappers.RoleAssignment
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getByIdOperationSpec = {
    httpMethod: "GET",
    path: "{roleId}",
    urlParameters: [
        Parameters.roleId
    ],
    queryParameters: [
        Parameters.apiVersion3
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoleAssignment
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Authorization/roleAssignments",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.filter,
        Parameters.apiVersion3
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoleAssignmentListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listForScopeOperationSpec = {
    httpMethod: "GET",
    path: "{scope}/providers/Microsoft.Authorization/roleAssignments",
    urlParameters: [
        Parameters.scope
    ],
    queryParameters: [
        Parameters.filter,
        Parameters.apiVersion3
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoleAssignmentListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listForResourceNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoleAssignmentListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listForResourceGroupNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoleAssignmentListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoleAssignmentListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listForScopeNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RoleAssignmentListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=roleAssignments.js.map