import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { AuthorizationManagementClientContext } from "../authorizationManagementClientContext";
/** Class representing a RoleDefinitions. */
export declare class RoleDefinitions {
    private readonly client;
    /**
     * Create a RoleDefinitions.
     * @param {AuthorizationManagementClientContext} client Reference to the service client.
     */
    constructor(client: AuthorizationManagementClientContext);
    /**
     * Deletes a role definition.
     * @param scope The scope of the role definition.
     * @param roleDefinitionId The ID of the role definition to delete.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleDefinitionsDeleteMethodResponse>
     */
    deleteMethod(scope: string, roleDefinitionId: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleDefinitionsDeleteMethodResponse>;
    /**
     * @param scope The scope of the role definition.
     * @param roleDefinitionId The ID of the role definition to delete.
     * @param callback The callback
     */
    deleteMethod(scope: string, roleDefinitionId: string, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
    /**
     * @param scope The scope of the role definition.
     * @param roleDefinitionId The ID of the role definition to delete.
     * @param options The optional parameters
     * @param callback The callback
     */
    deleteMethod(scope: string, roleDefinitionId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
    /**
     * Get role definition by name (GUID).
     * @param scope The scope of the role definition.
     * @param roleDefinitionId The ID of the role definition.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleDefinitionsGetResponse>
     */
    get(scope: string, roleDefinitionId: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleDefinitionsGetResponse>;
    /**
     * @param scope The scope of the role definition.
     * @param roleDefinitionId The ID of the role definition.
     * @param callback The callback
     */
    get(scope: string, roleDefinitionId: string, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
    /**
     * @param scope The scope of the role definition.
     * @param roleDefinitionId The ID of the role definition.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(scope: string, roleDefinitionId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
    /**
     * Creates or updates a role definition.
     * @param scope The scope of the role definition.
     * @param roleDefinitionId The ID of the role definition.
     * @param roleDefinition The values for the role definition.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleDefinitionsCreateOrUpdateResponse>
     */
    createOrUpdate(scope: string, roleDefinitionId: string, roleDefinition: Models.RoleDefinition, options?: msRest.RequestOptionsBase): Promise<Models.RoleDefinitionsCreateOrUpdateResponse>;
    /**
     * @param scope The scope of the role definition.
     * @param roleDefinitionId The ID of the role definition.
     * @param roleDefinition The values for the role definition.
     * @param callback The callback
     */
    createOrUpdate(scope: string, roleDefinitionId: string, roleDefinition: Models.RoleDefinition, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
    /**
     * @param scope The scope of the role definition.
     * @param roleDefinitionId The ID of the role definition.
     * @param roleDefinition The values for the role definition.
     * @param options The optional parameters
     * @param callback The callback
     */
    createOrUpdate(scope: string, roleDefinitionId: string, roleDefinition: Models.RoleDefinition, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
    /**
     * Get all role definitions that are applicable at scope and above.
     * @param scope The scope of the role definition.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleDefinitionsListResponse>
     */
    list(scope: string, options?: Models.RoleDefinitionsListOptionalParams): Promise<Models.RoleDefinitionsListResponse>;
    /**
     * @param scope The scope of the role definition.
     * @param callback The callback
     */
    list(scope: string, callback: msRest.ServiceCallback<Models.RoleDefinitionListResult>): void;
    /**
     * @param scope The scope of the role definition.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(scope: string, options: Models.RoleDefinitionsListOptionalParams, callback: msRest.ServiceCallback<Models.RoleDefinitionListResult>): void;
    /**
     * Gets a role definition by ID.
     * @param roleId The fully qualified role definition ID. Use the format,
     * /subscriptions/{guid}/providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId} for
     * subscription level role definitions, or
     * /providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId} for tenant level role
     * definitions.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleDefinitionsGetByIdResponse>
     */
    getById(roleId: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleDefinitionsGetByIdResponse>;
    /**
     * @param roleId The fully qualified role definition ID. Use the format,
     * /subscriptions/{guid}/providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId} for
     * subscription level role definitions, or
     * /providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId} for tenant level role
     * definitions.
     * @param callback The callback
     */
    getById(roleId: string, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
    /**
     * @param roleId The fully qualified role definition ID. Use the format,
     * /subscriptions/{guid}/providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId} for
     * subscription level role definitions, or
     * /providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId} for tenant level role
     * definitions.
     * @param options The optional parameters
     * @param callback The callback
     */
    getById(roleId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
    /**
     * Get all role definitions that are applicable at scope and above.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoleDefinitionsListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleDefinitionsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.RoleDefinitionListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleDefinitionListResult>): void;
}
//# sourceMappingURL=roleDefinitions.d.ts.map