/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import * as Mappers from "../models/roleDefinitionsMappers";
import * as Parameters from "../models/parameters";
import { AuthorizationManagementClientContext } from "../authorizationManagementClientContext";

/** Class representing a RoleDefinitions. */
export class RoleDefinitions {
  private readonly client: AuthorizationManagementClientContext;

  /**
   * Create a RoleDefinitions.
   * @param {AuthorizationManagementClientContext} client Reference to the service client.
   */
  constructor(client: AuthorizationManagementClientContext) {
    this.client = client;
  }

  /**
   * Deletes a role definition.
   * @param scope The scope of the role definition.
   * @param roleDefinitionId The ID of the role definition to delete.
   * @param [options] The optional parameters
   * @returns Promise<Models.RoleDefinitionsDeleteMethodResponse>
   */
  deleteMethod(scope: string, roleDefinitionId: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleDefinitionsDeleteMethodResponse>;
  /**
   * @param scope The scope of the role definition.
   * @param roleDefinitionId The ID of the role definition to delete.
   * @param callback The callback
   */
  deleteMethod(scope: string, roleDefinitionId: string, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
  /**
   * @param scope The scope of the role definition.
   * @param roleDefinitionId The ID of the role definition to delete.
   * @param options The optional parameters
   * @param callback The callback
   */
  deleteMethod(scope: string, roleDefinitionId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
  deleteMethod(scope: string, roleDefinitionId: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.RoleDefinition>, callback?: msRest.ServiceCallback<Models.RoleDefinition>): Promise<Models.RoleDefinitionsDeleteMethodResponse> {
    return this.client.sendOperationRequest(
      {
        scope,
        roleDefinitionId,
        options
      },
      deleteMethodOperationSpec,
      callback) as Promise<Models.RoleDefinitionsDeleteMethodResponse>;
  }

  /**
   * Get role definition by name (GUID).
   * @param scope The scope of the role definition.
   * @param roleDefinitionId The ID of the role definition.
   * @param [options] The optional parameters
   * @returns Promise<Models.RoleDefinitionsGetResponse>
   */
  get(scope: string, roleDefinitionId: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleDefinitionsGetResponse>;
  /**
   * @param scope The scope of the role definition.
   * @param roleDefinitionId The ID of the role definition.
   * @param callback The callback
   */
  get(scope: string, roleDefinitionId: string, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
  /**
   * @param scope The scope of the role definition.
   * @param roleDefinitionId The ID of the role definition.
   * @param options The optional parameters
   * @param callback The callback
   */
  get(scope: string, roleDefinitionId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
  get(scope: string, roleDefinitionId: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.RoleDefinition>, callback?: msRest.ServiceCallback<Models.RoleDefinition>): Promise<Models.RoleDefinitionsGetResponse> {
    return this.client.sendOperationRequest(
      {
        scope,
        roleDefinitionId,
        options
      },
      getOperationSpec,
      callback) as Promise<Models.RoleDefinitionsGetResponse>;
  }

  /**
   * Creates or updates a role definition.
   * @param scope The scope of the role definition.
   * @param roleDefinitionId The ID of the role definition.
   * @param roleDefinition The values for the role definition.
   * @param [options] The optional parameters
   * @returns Promise<Models.RoleDefinitionsCreateOrUpdateResponse>
   */
  createOrUpdate(scope: string, roleDefinitionId: string, roleDefinition: Models.RoleDefinition, options?: msRest.RequestOptionsBase): Promise<Models.RoleDefinitionsCreateOrUpdateResponse>;
  /**
   * @param scope The scope of the role definition.
   * @param roleDefinitionId The ID of the role definition.
   * @param roleDefinition The values for the role definition.
   * @param callback The callback
   */
  createOrUpdate(scope: string, roleDefinitionId: string, roleDefinition: Models.RoleDefinition, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
  /**
   * @param scope The scope of the role definition.
   * @param roleDefinitionId The ID of the role definition.
   * @param roleDefinition The values for the role definition.
   * @param options The optional parameters
   * @param callback The callback
   */
  createOrUpdate(scope: string, roleDefinitionId: string, roleDefinition: Models.RoleDefinition, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
  createOrUpdate(scope: string, roleDefinitionId: string, roleDefinition: Models.RoleDefinition, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.RoleDefinition>, callback?: msRest.ServiceCallback<Models.RoleDefinition>): Promise<Models.RoleDefinitionsCreateOrUpdateResponse> {
    return this.client.sendOperationRequest(
      {
        scope,
        roleDefinitionId,
        roleDefinition,
        options
      },
      createOrUpdateOperationSpec,
      callback) as Promise<Models.RoleDefinitionsCreateOrUpdateResponse>;
  }

  /**
   * Get all role definitions that are applicable at scope and above.
   * @param scope The scope of the role definition.
   * @param [options] The optional parameters
   * @returns Promise<Models.RoleDefinitionsListResponse>
   */
  list(scope: string, options?: Models.RoleDefinitionsListOptionalParams): Promise<Models.RoleDefinitionsListResponse>;
  /**
   * @param scope The scope of the role definition.
   * @param callback The callback
   */
  list(scope: string, callback: msRest.ServiceCallback<Models.RoleDefinitionListResult>): void;
  /**
   * @param scope The scope of the role definition.
   * @param options The optional parameters
   * @param callback The callback
   */
  list(scope: string, options: Models.RoleDefinitionsListOptionalParams, callback: msRest.ServiceCallback<Models.RoleDefinitionListResult>): void;
  list(scope: string, options?: Models.RoleDefinitionsListOptionalParams | msRest.ServiceCallback<Models.RoleDefinitionListResult>, callback?: msRest.ServiceCallback<Models.RoleDefinitionListResult>): Promise<Models.RoleDefinitionsListResponse> {
    return this.client.sendOperationRequest(
      {
        scope,
        options
      },
      listOperationSpec,
      callback) as Promise<Models.RoleDefinitionsListResponse>;
  }

  /**
   * Gets a role definition by ID.
   * @param roleId The fully qualified role definition ID. Use the format,
   * /subscriptions/{guid}/providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId} for
   * subscription level role definitions, or
   * /providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId} for tenant level role
   * definitions.
   * @param [options] The optional parameters
   * @returns Promise<Models.RoleDefinitionsGetByIdResponse>
   */
  getById(roleId: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleDefinitionsGetByIdResponse>;
  /**
   * @param roleId The fully qualified role definition ID. Use the format,
   * /subscriptions/{guid}/providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId} for
   * subscription level role definitions, or
   * /providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId} for tenant level role
   * definitions.
   * @param callback The callback
   */
  getById(roleId: string, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
  /**
   * @param roleId The fully qualified role definition ID. Use the format,
   * /subscriptions/{guid}/providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId} for
   * subscription level role definitions, or
   * /providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId} for tenant level role
   * definitions.
   * @param options The optional parameters
   * @param callback The callback
   */
  getById(roleId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleDefinition>): void;
  getById(roleId: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.RoleDefinition>, callback?: msRest.ServiceCallback<Models.RoleDefinition>): Promise<Models.RoleDefinitionsGetByIdResponse> {
    return this.client.sendOperationRequest(
      {
        roleId,
        options
      },
      getByIdOperationSpec,
      callback) as Promise<Models.RoleDefinitionsGetByIdResponse>;
  }

  /**
   * Get all role definitions that are applicable at scope and above.
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.RoleDefinitionsListNextResponse>
   */
  listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.RoleDefinitionsListNextResponse>;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param callback The callback
   */
  listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.RoleDefinitionListResult>): void;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RoleDefinitionListResult>): void;
  listNext(nextPageLink: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.RoleDefinitionListResult>, callback?: msRest.ServiceCallback<Models.RoleDefinitionListResult>): Promise<Models.RoleDefinitionsListNextResponse> {
    return this.client.sendOperationRequest(
      {
        nextPageLink,
        options
      },
      listNextOperationSpec,
      callback) as Promise<Models.RoleDefinitionsListNextResponse>;
  }
}

// Operation Specifications
const serializer = new msRest.Serializer(Mappers);
const deleteMethodOperationSpec: msRest.OperationSpec = {
  httpMethod: "DELETE",
  path: "{scope}/providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId}",
  urlParameters: [
    Parameters.scope,
    Parameters.roleDefinitionId
  ],
  queryParameters: [
    Parameters.apiVersion2
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.RoleDefinition
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const getOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "{scope}/providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId}",
  urlParameters: [
    Parameters.scope,
    Parameters.roleDefinitionId
  ],
  queryParameters: [
    Parameters.apiVersion2
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.RoleDefinition
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const createOrUpdateOperationSpec: msRest.OperationSpec = {
  httpMethod: "PUT",
  path: "{scope}/providers/Microsoft.Authorization/roleDefinitions/{roleDefinitionId}",
  urlParameters: [
    Parameters.scope,
    Parameters.roleDefinitionId
  ],
  queryParameters: [
    Parameters.apiVersion2
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  requestBody: {
    parameterPath: "roleDefinition",
    mapper: {
      ...Mappers.RoleDefinition,
      required: true
    }
  },
  responses: {
    201: {
      bodyMapper: Mappers.RoleDefinition
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "{scope}/providers/Microsoft.Authorization/roleDefinitions",
  urlParameters: [
    Parameters.scope
  ],
  queryParameters: [
    Parameters.filter,
    Parameters.apiVersion2
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.RoleDefinitionListResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const getByIdOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "{roleId}",
  urlParameters: [
    Parameters.roleId
  ],
  queryParameters: [
    Parameters.apiVersion2
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.RoleDefinition
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listNextOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  baseUrl: "https://management.azure.com",
  path: "{nextLink}",
  urlParameters: [
    Parameters.nextPageLink
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.RoleDefinitionListResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};
