import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { AzureADOnlyAuthentications } from "../operationsInterfaces";
import { SynapseManagementClient } from "../synapseManagementClient";
import { PollerLike, PollOperationState } from "@azure/core-lro";
import { AzureADOnlyAuthentication, AzureADOnlyAuthenticationsListOptionalParams, AzureADOnlyAuthenticationName, AzureADOnlyAuthenticationsGetOptionalParams, AzureADOnlyAuthenticationsGetResponse, AzureADOnlyAuthenticationsCreateOptionalParams, AzureADOnlyAuthenticationsCreateResponse } from "../models";
/** Class containing AzureADOnlyAuthentications operations. */
export declare class AzureADOnlyAuthenticationsImpl implements AzureADOnlyAuthentications {
    private readonly client;
    /**
     * Initialize a new instance of the class AzureADOnlyAuthentications class.
     * @param client Reference to the service client
     */
    constructor(client: SynapseManagementClient);
    /**
     * Gets a list of Azure Active Directory only authentication property for a workspace
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param options The options parameters.
     */
    list(resourceGroupName: string, workspaceName: string, options?: AzureADOnlyAuthenticationsListOptionalParams): PagedAsyncIterableIterator<AzureADOnlyAuthentication>;
    private listPagingPage;
    private listPagingAll;
    /**
     * Gets a Azure Active Directory only authentication property
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param azureADOnlyAuthenticationName name of the property
     * @param options The options parameters.
     */
    get(resourceGroupName: string, workspaceName: string, azureADOnlyAuthenticationName: AzureADOnlyAuthenticationName, options?: AzureADOnlyAuthenticationsGetOptionalParams): Promise<AzureADOnlyAuthenticationsGetResponse>;
    /**
     * Create or Update a Azure Active Directory only authentication property for the workspaces
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param azureADOnlyAuthenticationName name of the property
     * @param azureADOnlyAuthenticationInfo Azure Active Directory Property
     * @param options The options parameters.
     */
    beginCreate(resourceGroupName: string, workspaceName: string, azureADOnlyAuthenticationName: AzureADOnlyAuthenticationName, azureADOnlyAuthenticationInfo: AzureADOnlyAuthentication, options?: AzureADOnlyAuthenticationsCreateOptionalParams): Promise<PollerLike<PollOperationState<AzureADOnlyAuthenticationsCreateResponse>, AzureADOnlyAuthenticationsCreateResponse>>;
    /**
     * Create or Update a Azure Active Directory only authentication property for the workspaces
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param azureADOnlyAuthenticationName name of the property
     * @param azureADOnlyAuthenticationInfo Azure Active Directory Property
     * @param options The options parameters.
     */
    beginCreateAndWait(resourceGroupName: string, workspaceName: string, azureADOnlyAuthenticationName: AzureADOnlyAuthenticationName, azureADOnlyAuthenticationInfo: AzureADOnlyAuthentication, options?: AzureADOnlyAuthenticationsCreateOptionalParams): Promise<AzureADOnlyAuthenticationsCreateResponse>;
    /**
     * Gets a list of Azure Active Directory only authentication property for a workspace
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param options The options parameters.
     */
    private _list;
    /**
     * ListNext
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param nextLink The nextLink from the previous successful call to the List method.
     * @param options The options parameters.
     */
    private _listNext;
}
//# sourceMappingURL=azureADOnlyAuthentications.d.ts.map