import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { PrivateLinkHubs } from "../operationsInterfaces";
import { SynapseManagementClient } from "../synapseManagementClient";
import { PollerLike, PollOperationState } from "@azure/core-lro";
import { PrivateLinkHub, PrivateLinkHubsListByResourceGroupOptionalParams, PrivateLinkHubsListOptionalParams, PrivateLinkHubsGetOptionalParams, PrivateLinkHubsGetResponse, PrivateLinkHubPatchInfo, PrivateLinkHubsUpdateOptionalParams, PrivateLinkHubsUpdateResponse, PrivateLinkHubsCreateOrUpdateOptionalParams, PrivateLinkHubsCreateOrUpdateResponse, PrivateLinkHubsDeleteOptionalParams } from "../models";
/** Class containing PrivateLinkHubs operations. */
export declare class PrivateLinkHubsImpl implements PrivateLinkHubs {
    private readonly client;
    /**
     * Initialize a new instance of the class PrivateLinkHubs class.
     * @param client Reference to the service client
     */
    constructor(client: SynapseManagementClient);
    /**
     * Returns a list of privateLinkHubs in a resource group
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param options The options parameters.
     */
    listByResourceGroup(resourceGroupName: string, options?: PrivateLinkHubsListByResourceGroupOptionalParams): PagedAsyncIterableIterator<PrivateLinkHub>;
    private listByResourceGroupPagingPage;
    private listByResourceGroupPagingAll;
    /**
     * Returns a list of privateLinkHubs in a subscription
     * @param options The options parameters.
     */
    list(options?: PrivateLinkHubsListOptionalParams): PagedAsyncIterableIterator<PrivateLinkHub>;
    private listPagingPage;
    private listPagingAll;
    /**
     * Returns a list of privateLinkHubs in a resource group
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param options The options parameters.
     */
    private _listByResourceGroup;
    /**
     * Gets a privateLinkHub
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param privateLinkHubName Name of the privateLinkHub
     * @param options The options parameters.
     */
    get(resourceGroupName: string, privateLinkHubName: string, options?: PrivateLinkHubsGetOptionalParams): Promise<PrivateLinkHubsGetResponse>;
    /**
     * Updates a privateLinkHub
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param privateLinkHubName Name of the privateLinkHub
     * @param privateLinkHubPatchInfo PrivateLinkHub patch request properties
     * @param options The options parameters.
     */
    update(resourceGroupName: string, privateLinkHubName: string, privateLinkHubPatchInfo: PrivateLinkHubPatchInfo, options?: PrivateLinkHubsUpdateOptionalParams): Promise<PrivateLinkHubsUpdateResponse>;
    /**
     * Creates or updates a privateLinkHub
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param privateLinkHubName Name of the privateLinkHub
     * @param privateLinkHubInfo PrivateLinkHub create or update request properties
     * @param options The options parameters.
     */
    createOrUpdate(resourceGroupName: string, privateLinkHubName: string, privateLinkHubInfo: PrivateLinkHub, options?: PrivateLinkHubsCreateOrUpdateOptionalParams): Promise<PrivateLinkHubsCreateOrUpdateResponse>;
    /**
     * Deletes a privateLinkHub
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param privateLinkHubName Name of the privateLinkHub
     * @param options The options parameters.
     */
    beginDelete(resourceGroupName: string, privateLinkHubName: string, options?: PrivateLinkHubsDeleteOptionalParams): Promise<PollerLike<PollOperationState<void>, void>>;
    /**
     * Deletes a privateLinkHub
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param privateLinkHubName Name of the privateLinkHub
     * @param options The options parameters.
     */
    beginDeleteAndWait(resourceGroupName: string, privateLinkHubName: string, options?: PrivateLinkHubsDeleteOptionalParams): Promise<void>;
    /**
     * Returns a list of privateLinkHubs in a subscription
     * @param options The options parameters.
     */
    private _list;
    /**
     * ListByResourceGroupNext
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param nextLink The nextLink from the previous successful call to the ListByResourceGroup method.
     * @param options The options parameters.
     */
    private _listByResourceGroupNext;
    /**
     * ListNext
     * @param nextLink The nextLink from the previous successful call to the List method.
     * @param options The options parameters.
     */
    private _listNext;
}
//# sourceMappingURL=privateLinkHubs.d.ts.map