import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { SqlPoolOperations } from "../operationsInterfaces";
import { SynapseManagementClient } from "../synapseManagementClient";
import { SqlPoolOperation, SqlPoolOperationsListOptionalParams } from "../models";
/** Class containing SqlPoolOperations operations. */
export declare class SqlPoolOperationsImpl implements SqlPoolOperations {
    private readonly client;
    /**
     * Initialize a new instance of the class SqlPoolOperations class.
     * @param client Reference to the service client
     */
    constructor(client: SynapseManagementClient);
    /**
     * Gets a list of operations performed on the SQL pool.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param options The options parameters.
     */
    list(resourceGroupName: string, workspaceName: string, sqlPoolName: string, options?: SqlPoolOperationsListOptionalParams): PagedAsyncIterableIterator<SqlPoolOperation>;
    private listPagingPage;
    private listPagingAll;
    /**
     * Gets a list of operations performed on the SQL pool.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param options The options parameters.
     */
    private _list;
    /**
     * ListNext
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param nextLink The nextLink from the previous successful call to the List method.
     * @param options The options parameters.
     */
    private _listNext;
}
//# sourceMappingURL=sqlPoolOperations.d.ts.map