import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { SqlPoolSchemas } from "../operationsInterfaces";
import { SynapseManagementClient } from "../synapseManagementClient";
import { SqlPoolSchema, SqlPoolSchemasListOptionalParams, SqlPoolSchemasGetOptionalParams, SqlPoolSchemasGetResponse } from "../models";
/** Class containing SqlPoolSchemas operations. */
export declare class SqlPoolSchemasImpl implements SqlPoolSchemas {
    private readonly client;
    /**
     * Initialize a new instance of the class SqlPoolSchemas class.
     * @param client Reference to the service client
     */
    constructor(client: SynapseManagementClient);
    /**
     * Gets schemas of a given SQL pool.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param options The options parameters.
     */
    list(resourceGroupName: string, workspaceName: string, sqlPoolName: string, options?: SqlPoolSchemasListOptionalParams): PagedAsyncIterableIterator<SqlPoolSchema>;
    private listPagingPage;
    private listPagingAll;
    /**
     * Gets schemas of a given SQL pool.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param options The options parameters.
     */
    private _list;
    /**
     * Get Sql Pool schema
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param schemaName The name of the schema.
     * @param options The options parameters.
     */
    get(resourceGroupName: string, workspaceName: string, sqlPoolName: string, schemaName: string, options?: SqlPoolSchemasGetOptionalParams): Promise<SqlPoolSchemasGetResponse>;
    /**
     * ListNext
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param nextLink The nextLink from the previous successful call to the List method.
     * @param options The options parameters.
     */
    private _listNext;
}
//# sourceMappingURL=sqlPoolSchemas.d.ts.map