import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { SqlPoolTables } from "../operationsInterfaces";
import { SynapseManagementClient } from "../synapseManagementClient";
import { SqlPoolTable, SqlPoolTablesListBySchemaOptionalParams, SqlPoolTablesGetOptionalParams, SqlPoolTablesGetResponse } from "../models";
/** Class containing SqlPoolTables operations. */
export declare class SqlPoolTablesImpl implements SqlPoolTables {
    private readonly client;
    /**
     * Initialize a new instance of the class SqlPoolTables class.
     * @param client Reference to the service client
     */
    constructor(client: SynapseManagementClient);
    /**
     * Gets tables of a given schema in a SQL pool.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param schemaName The name of the schema.
     * @param options The options parameters.
     */
    listBySchema(resourceGroupName: string, workspaceName: string, sqlPoolName: string, schemaName: string, options?: SqlPoolTablesListBySchemaOptionalParams): PagedAsyncIterableIterator<SqlPoolTable>;
    private listBySchemaPagingPage;
    private listBySchemaPagingAll;
    /**
     * Gets tables of a given schema in a SQL pool.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param schemaName The name of the schema.
     * @param options The options parameters.
     */
    private _listBySchema;
    /**
     * Get Sql pool table
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param schemaName The name of the schema.
     * @param tableName The name of the table.
     * @param options The options parameters.
     */
    get(resourceGroupName: string, workspaceName: string, sqlPoolName: string, schemaName: string, tableName: string, options?: SqlPoolTablesGetOptionalParams): Promise<SqlPoolTablesGetResponse>;
    /**
     * ListBySchemaNext
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param schemaName The name of the schema.
     * @param nextLink The nextLink from the previous successful call to the ListBySchema method.
     * @param options The options parameters.
     */
    private _listBySchemaNext;
}
//# sourceMappingURL=sqlPoolTables.d.ts.map