import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { WorkspaceManagedSqlServerBlobAuditingPolicies } from "../operationsInterfaces";
import { SynapseManagementClient } from "../synapseManagementClient";
import { PollerLike, PollOperationState } from "@azure/core-lro";
import { ServerBlobAuditingPolicy, WorkspaceManagedSqlServerBlobAuditingPoliciesListByWorkspaceOptionalParams, BlobAuditingPolicyName, WorkspaceManagedSqlServerBlobAuditingPoliciesGetOptionalParams, WorkspaceManagedSqlServerBlobAuditingPoliciesGetResponse, WorkspaceManagedSqlServerBlobAuditingPoliciesCreateOrUpdateOptionalParams, WorkspaceManagedSqlServerBlobAuditingPoliciesCreateOrUpdateResponse } from "../models";
/** Class containing WorkspaceManagedSqlServerBlobAuditingPolicies operations. */
export declare class WorkspaceManagedSqlServerBlobAuditingPoliciesImpl implements WorkspaceManagedSqlServerBlobAuditingPolicies {
    private readonly client;
    /**
     * Initialize a new instance of the class WorkspaceManagedSqlServerBlobAuditingPolicies class.
     * @param client Reference to the service client
     */
    constructor(client: SynapseManagementClient);
    /**
     * List workspace managed sql server's blob auditing policies.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param options The options parameters.
     */
    listByWorkspace(resourceGroupName: string, workspaceName: string, options?: WorkspaceManagedSqlServerBlobAuditingPoliciesListByWorkspaceOptionalParams): PagedAsyncIterableIterator<ServerBlobAuditingPolicy>;
    private listByWorkspacePagingPage;
    private listByWorkspacePagingAll;
    /**
     * Get a workspace managed sql server's blob auditing policy.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param blobAuditingPolicyName The name of the blob auditing policy.
     * @param options The options parameters.
     */
    get(resourceGroupName: string, workspaceName: string, blobAuditingPolicyName: BlobAuditingPolicyName, options?: WorkspaceManagedSqlServerBlobAuditingPoliciesGetOptionalParams): Promise<WorkspaceManagedSqlServerBlobAuditingPoliciesGetResponse>;
    /**
     * Create or Update a workspace managed sql server's blob auditing policy.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param blobAuditingPolicyName The name of the blob auditing policy.
     * @param parameters Properties of extended blob auditing policy.
     * @param options The options parameters.
     */
    beginCreateOrUpdate(resourceGroupName: string, workspaceName: string, blobAuditingPolicyName: BlobAuditingPolicyName, parameters: ServerBlobAuditingPolicy, options?: WorkspaceManagedSqlServerBlobAuditingPoliciesCreateOrUpdateOptionalParams): Promise<PollerLike<PollOperationState<WorkspaceManagedSqlServerBlobAuditingPoliciesCreateOrUpdateResponse>, WorkspaceManagedSqlServerBlobAuditingPoliciesCreateOrUpdateResponse>>;
    /**
     * Create or Update a workspace managed sql server's blob auditing policy.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param blobAuditingPolicyName The name of the blob auditing policy.
     * @param parameters Properties of extended blob auditing policy.
     * @param options The options parameters.
     */
    beginCreateOrUpdateAndWait(resourceGroupName: string, workspaceName: string, blobAuditingPolicyName: BlobAuditingPolicyName, parameters: ServerBlobAuditingPolicy, options?: WorkspaceManagedSqlServerBlobAuditingPoliciesCreateOrUpdateOptionalParams): Promise<WorkspaceManagedSqlServerBlobAuditingPoliciesCreateOrUpdateResponse>;
    /**
     * List workspace managed sql server's blob auditing policies.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param options The options parameters.
     */
    private _listByWorkspace;
    /**
     * ListByWorkspaceNext
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param nextLink The nextLink from the previous successful call to the ListByWorkspace method.
     * @param options The options parameters.
     */
    private _listByWorkspaceNext;
}
//# sourceMappingURL=workspaceManagedSqlServerBlobAuditingPolicies.d.ts.map