import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { WorkspaceManagedSqlServerExtendedBlobAuditingPolicies } from "../operationsInterfaces";
import { SynapseManagementClient } from "../synapseManagementClient";
import { PollerLike, PollOperationState } from "@azure/core-lro";
import { ExtendedServerBlobAuditingPolicy, WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesListByWorkspaceOptionalParams, BlobAuditingPolicyName, WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesGetOptionalParams, WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesGetResponse, WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesCreateOrUpdateOptionalParams, WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesCreateOrUpdateResponse } from "../models";
/** Class containing WorkspaceManagedSqlServerExtendedBlobAuditingPolicies operations. */
export declare class WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesImpl implements WorkspaceManagedSqlServerExtendedBlobAuditingPolicies {
    private readonly client;
    /**
     * Initialize a new instance of the class WorkspaceManagedSqlServerExtendedBlobAuditingPolicies class.
     * @param client Reference to the service client
     */
    constructor(client: SynapseManagementClient);
    /**
     * List workspace managed sql server's extended blob auditing policies.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param options The options parameters.
     */
    listByWorkspace(resourceGroupName: string, workspaceName: string, options?: WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesListByWorkspaceOptionalParams): PagedAsyncIterableIterator<ExtendedServerBlobAuditingPolicy>;
    private listByWorkspacePagingPage;
    private listByWorkspacePagingAll;
    /**
     * Get a workspace SQL server's extended blob auditing policy.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param blobAuditingPolicyName The name of the blob auditing policy.
     * @param options The options parameters.
     */
    get(resourceGroupName: string, workspaceName: string, blobAuditingPolicyName: BlobAuditingPolicyName, options?: WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesGetOptionalParams): Promise<WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesGetResponse>;
    /**
     * Create or Update a workspace managed sql server's extended blob auditing policy.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param blobAuditingPolicyName The name of the blob auditing policy.
     * @param parameters Properties of extended blob auditing policy.
     * @param options The options parameters.
     */
    beginCreateOrUpdate(resourceGroupName: string, workspaceName: string, blobAuditingPolicyName: BlobAuditingPolicyName, parameters: ExtendedServerBlobAuditingPolicy, options?: WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesCreateOrUpdateOptionalParams): Promise<PollerLike<PollOperationState<WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesCreateOrUpdateResponse>, WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesCreateOrUpdateResponse>>;
    /**
     * Create or Update a workspace managed sql server's extended blob auditing policy.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param blobAuditingPolicyName The name of the blob auditing policy.
     * @param parameters Properties of extended blob auditing policy.
     * @param options The options parameters.
     */
    beginCreateOrUpdateAndWait(resourceGroupName: string, workspaceName: string, blobAuditingPolicyName: BlobAuditingPolicyName, parameters: ExtendedServerBlobAuditingPolicy, options?: WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesCreateOrUpdateOptionalParams): Promise<WorkspaceManagedSqlServerExtendedBlobAuditingPoliciesCreateOrUpdateResponse>;
    /**
     * List workspace managed sql server's extended blob auditing policies.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param options The options parameters.
     */
    private _listByWorkspace;
    /**
     * ListByWorkspaceNext
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param nextLink The nextLink from the previous successful call to the ListByWorkspace method.
     * @param options The options parameters.
     */
    private _listByWorkspaceNext;
}
//# sourceMappingURL=workspaceManagedSqlServerExtendedBlobAuditingPolicies.d.ts.map