import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { ExtendedSqlPoolBlobAuditingPolicy, ExtendedSqlPoolBlobAuditingPoliciesListBySqlPoolOptionalParams, ExtendedSqlPoolBlobAuditingPoliciesGetOptionalParams, ExtendedSqlPoolBlobAuditingPoliciesGetResponse, ExtendedSqlPoolBlobAuditingPoliciesCreateOrUpdateOptionalParams, ExtendedSqlPoolBlobAuditingPoliciesCreateOrUpdateResponse } from "../models";
/** Interface representing a ExtendedSqlPoolBlobAuditingPolicies. */
export interface ExtendedSqlPoolBlobAuditingPolicies {
    /**
     * Lists extended auditing settings of a Sql pool.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param options The options parameters.
     */
    listBySqlPool(resourceGroupName: string, workspaceName: string, sqlPoolName: string, options?: ExtendedSqlPoolBlobAuditingPoliciesListBySqlPoolOptionalParams): PagedAsyncIterableIterator<ExtendedSqlPoolBlobAuditingPolicy>;
    /**
     * Gets an extended Sql pool's blob auditing policy.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param options The options parameters.
     */
    get(resourceGroupName: string, workspaceName: string, sqlPoolName: string, options?: ExtendedSqlPoolBlobAuditingPoliciesGetOptionalParams): Promise<ExtendedSqlPoolBlobAuditingPoliciesGetResponse>;
    /**
     * Creates or updates an extended Sql pool's blob auditing policy.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param parameters The extended Sql pool blob auditing policy.
     * @param options The options parameters.
     */
    createOrUpdate(resourceGroupName: string, workspaceName: string, sqlPoolName: string, parameters: ExtendedSqlPoolBlobAuditingPolicy, options?: ExtendedSqlPoolBlobAuditingPoliciesCreateOrUpdateOptionalParams): Promise<ExtendedSqlPoolBlobAuditingPoliciesCreateOrUpdateResponse>;
}
//# sourceMappingURL=extendedSqlPoolBlobAuditingPolicies.d.ts.map