import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { SensitivityLabel, SqlPoolSensitivityLabelsListCurrentOptionalParams, SqlPoolSensitivityLabelsListRecommendedOptionalParams, SensitivityLabelUpdateList, SqlPoolSensitivityLabelsUpdateOptionalParams, SqlPoolSensitivityLabelsCreateOrUpdateOptionalParams, SqlPoolSensitivityLabelsCreateOrUpdateResponse, SqlPoolSensitivityLabelsDeleteOptionalParams, SensitivityLabelSource, SqlPoolSensitivityLabelsGetOptionalParams, SqlPoolSensitivityLabelsGetResponse, SqlPoolSensitivityLabelsEnableRecommendationOptionalParams, SqlPoolSensitivityLabelsDisableRecommendationOptionalParams } from "../models";
/** Interface representing a SqlPoolSensitivityLabels. */
export interface SqlPoolSensitivityLabels {
    /**
     * Gets SQL pool sensitivity labels.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param options The options parameters.
     */
    listCurrent(resourceGroupName: string, workspaceName: string, sqlPoolName: string, options?: SqlPoolSensitivityLabelsListCurrentOptionalParams): PagedAsyncIterableIterator<SensitivityLabel>;
    /**
     * Gets sensitivity labels of a given SQL pool.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param options The options parameters.
     */
    listRecommended(resourceGroupName: string, workspaceName: string, sqlPoolName: string, options?: SqlPoolSensitivityLabelsListRecommendedOptionalParams): PagedAsyncIterableIterator<SensitivityLabel>;
    /**
     * Update sensitivity labels of a given SQL Pool using an operations batch.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param parameters A list of sensitivity label update operations.
     * @param options The options parameters.
     */
    update(resourceGroupName: string, workspaceName: string, sqlPoolName: string, parameters: SensitivityLabelUpdateList, options?: SqlPoolSensitivityLabelsUpdateOptionalParams): Promise<void>;
    /**
     * Creates or updates the sensitivity label of a given column in a Sql pool
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param schemaName The name of the schema.
     * @param tableName The name of the table.
     * @param columnName The name of the column.
     * @param parameters The column sensitivity label resource.
     * @param options The options parameters.
     */
    createOrUpdate(resourceGroupName: string, workspaceName: string, sqlPoolName: string, schemaName: string, tableName: string, columnName: string, parameters: SensitivityLabel, options?: SqlPoolSensitivityLabelsCreateOrUpdateOptionalParams): Promise<SqlPoolSensitivityLabelsCreateOrUpdateResponse>;
    /**
     * Deletes the sensitivity label of a given column in a Sql pool
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param schemaName The name of the schema.
     * @param tableName The name of the table.
     * @param columnName The name of the column.
     * @param options The options parameters.
     */
    delete(resourceGroupName: string, workspaceName: string, sqlPoolName: string, schemaName: string, tableName: string, columnName: string, options?: SqlPoolSensitivityLabelsDeleteOptionalParams): Promise<void>;
    /**
     * Gets the sensitivity label of a given column
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param schemaName The name of the schema.
     * @param tableName The name of the table.
     * @param columnName The name of the column.
     * @param sensitivityLabelSource The source of the sensitivity label.
     * @param options The options parameters.
     */
    get(resourceGroupName: string, workspaceName: string, sqlPoolName: string, schemaName: string, tableName: string, columnName: string, sensitivityLabelSource: SensitivityLabelSource, options?: SqlPoolSensitivityLabelsGetOptionalParams): Promise<SqlPoolSensitivityLabelsGetResponse>;
    /**
     * Enables sensitivity recommendations on a given column (recommendations are enabled by default on all
     * columns)
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param schemaName The name of the schema.
     * @param tableName The name of the table.
     * @param columnName The name of the column.
     * @param options The options parameters.
     */
    enableRecommendation(resourceGroupName: string, workspaceName: string, sqlPoolName: string, schemaName: string, tableName: string, columnName: string, options?: SqlPoolSensitivityLabelsEnableRecommendationOptionalParams): Promise<void>;
    /**
     * Disables sensitivity recommendations on a given column
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param sqlPoolName SQL pool name
     * @param schemaName The name of the schema.
     * @param tableName The name of the table.
     * @param columnName The name of the column.
     * @param options The options parameters.
     */
    disableRecommendation(resourceGroupName: string, workspaceName: string, sqlPoolName: string, schemaName: string, tableName: string, columnName: string, options?: SqlPoolSensitivityLabelsDisableRecommendationOptionalParams): Promise<void>;
}
//# sourceMappingURL=sqlPoolSensitivityLabels.d.ts.map