/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */

import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { KustoPoolAttachedDatabaseConfigurations } from "../operationsInterfaces";
import * as coreClient from "@azure/core-client";
import * as Mappers from "../models/mappers";
import * as Parameters from "../models/parameters";
import { SynapseManagementClient } from "../synapseManagementClient";
import { PollerLike, PollOperationState, LroEngine } from "@azure/core-lro";
import { LroImpl } from "../lroImpl";
import {
  AttachedDatabaseConfiguration,
  KustoPoolAttachedDatabaseConfigurationsListByKustoPoolOptionalParams,
  KustoPoolAttachedDatabaseConfigurationsListByKustoPoolResponse,
  KustoPoolAttachedDatabaseConfigurationsGetOptionalParams,
  KustoPoolAttachedDatabaseConfigurationsGetResponse,
  KustoPoolAttachedDatabaseConfigurationsCreateOrUpdateOptionalParams,
  KustoPoolAttachedDatabaseConfigurationsCreateOrUpdateResponse,
  KustoPoolAttachedDatabaseConfigurationsDeleteOptionalParams
} from "../models";

/// <reference lib="esnext.asynciterable" />
/** Class containing KustoPoolAttachedDatabaseConfigurations operations. */
export class KustoPoolAttachedDatabaseConfigurationsImpl
  implements KustoPoolAttachedDatabaseConfigurations {
  private readonly client: SynapseManagementClient;

  /**
   * Initialize a new instance of the class KustoPoolAttachedDatabaseConfigurations class.
   * @param client Reference to the service client
   */
  constructor(client: SynapseManagementClient) {
    this.client = client;
  }

  /**
   * Returns the list of attached database configurations of the given Kusto Pool.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param options The options parameters.
   */
  public listByKustoPool(
    workspaceName: string,
    kustoPoolName: string,
    resourceGroupName: string,
    options?: KustoPoolAttachedDatabaseConfigurationsListByKustoPoolOptionalParams
  ): PagedAsyncIterableIterator<AttachedDatabaseConfiguration> {
    const iter = this.listByKustoPoolPagingAll(
      workspaceName,
      kustoPoolName,
      resourceGroupName,
      options
    );
    return {
      next() {
        return iter.next();
      },
      [Symbol.asyncIterator]() {
        return this;
      },
      byPage: () => {
        return this.listByKustoPoolPagingPage(
          workspaceName,
          kustoPoolName,
          resourceGroupName,
          options
        );
      }
    };
  }

  private async *listByKustoPoolPagingPage(
    workspaceName: string,
    kustoPoolName: string,
    resourceGroupName: string,
    options?: KustoPoolAttachedDatabaseConfigurationsListByKustoPoolOptionalParams
  ): AsyncIterableIterator<AttachedDatabaseConfiguration[]> {
    let result = await this._listByKustoPool(
      workspaceName,
      kustoPoolName,
      resourceGroupName,
      options
    );
    yield result.value || [];
  }

  private async *listByKustoPoolPagingAll(
    workspaceName: string,
    kustoPoolName: string,
    resourceGroupName: string,
    options?: KustoPoolAttachedDatabaseConfigurationsListByKustoPoolOptionalParams
  ): AsyncIterableIterator<AttachedDatabaseConfiguration> {
    for await (const page of this.listByKustoPoolPagingPage(
      workspaceName,
      kustoPoolName,
      resourceGroupName,
      options
    )) {
      yield* page;
    }
  }

  /**
   * Returns the list of attached database configurations of the given Kusto Pool.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param options The options parameters.
   */
  private _listByKustoPool(
    workspaceName: string,
    kustoPoolName: string,
    resourceGroupName: string,
    options?: KustoPoolAttachedDatabaseConfigurationsListByKustoPoolOptionalParams
  ): Promise<KustoPoolAttachedDatabaseConfigurationsListByKustoPoolResponse> {
    return this.client.sendOperationRequest(
      { workspaceName, kustoPoolName, resourceGroupName, options },
      listByKustoPoolOperationSpec
    );
  }

  /**
   * Returns an attached database configuration.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param attachedDatabaseConfigurationName The name of the attached database configuration.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param options The options parameters.
   */
  get(
    workspaceName: string,
    kustoPoolName: string,
    attachedDatabaseConfigurationName: string,
    resourceGroupName: string,
    options?: KustoPoolAttachedDatabaseConfigurationsGetOptionalParams
  ): Promise<KustoPoolAttachedDatabaseConfigurationsGetResponse> {
    return this.client.sendOperationRequest(
      {
        workspaceName,
        kustoPoolName,
        attachedDatabaseConfigurationName,
        resourceGroupName,
        options
      },
      getOperationSpec
    );
  }

  /**
   * Creates or updates an attached database configuration.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param attachedDatabaseConfigurationName The name of the attached database configuration.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param parameters The database parameters supplied to the CreateOrUpdate operation.
   * @param options The options parameters.
   */
  async beginCreateOrUpdate(
    workspaceName: string,
    kustoPoolName: string,
    attachedDatabaseConfigurationName: string,
    resourceGroupName: string,
    parameters: AttachedDatabaseConfiguration,
    options?: KustoPoolAttachedDatabaseConfigurationsCreateOrUpdateOptionalParams
  ): Promise<
    PollerLike<
      PollOperationState<
        KustoPoolAttachedDatabaseConfigurationsCreateOrUpdateResponse
      >,
      KustoPoolAttachedDatabaseConfigurationsCreateOrUpdateResponse
    >
  > {
    const directSendOperation = async (
      args: coreClient.OperationArguments,
      spec: coreClient.OperationSpec
    ): Promise<KustoPoolAttachedDatabaseConfigurationsCreateOrUpdateResponse> => {
      return this.client.sendOperationRequest(args, spec);
    };
    const sendOperation = async (
      args: coreClient.OperationArguments,
      spec: coreClient.OperationSpec
    ) => {
      let currentRawResponse:
        | coreClient.FullOperationResponse
        | undefined = undefined;
      const providedCallback = args.options?.onResponse;
      const callback: coreClient.RawResponseCallback = (
        rawResponse: coreClient.FullOperationResponse,
        flatResponse: unknown
      ) => {
        currentRawResponse = rawResponse;
        providedCallback?.(rawResponse, flatResponse);
      };
      const updatedArgs = {
        ...args,
        options: {
          ...args.options,
          onResponse: callback
        }
      };
      const flatResponse = await directSendOperation(updatedArgs, spec);
      return {
        flatResponse,
        rawResponse: {
          statusCode: currentRawResponse!.status,
          body: currentRawResponse!.parsedBody,
          headers: currentRawResponse!.headers.toJSON()
        }
      };
    };

    const lro = new LroImpl(
      sendOperation,
      {
        workspaceName,
        kustoPoolName,
        attachedDatabaseConfigurationName,
        resourceGroupName,
        parameters,
        options
      },
      createOrUpdateOperationSpec
    );
    return new LroEngine(lro, {
      resumeFrom: options?.resumeFrom,
      intervalInMs: options?.updateIntervalInMs
    });
  }

  /**
   * Creates or updates an attached database configuration.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param attachedDatabaseConfigurationName The name of the attached database configuration.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param parameters The database parameters supplied to the CreateOrUpdate operation.
   * @param options The options parameters.
   */
  async beginCreateOrUpdateAndWait(
    workspaceName: string,
    kustoPoolName: string,
    attachedDatabaseConfigurationName: string,
    resourceGroupName: string,
    parameters: AttachedDatabaseConfiguration,
    options?: KustoPoolAttachedDatabaseConfigurationsCreateOrUpdateOptionalParams
  ): Promise<KustoPoolAttachedDatabaseConfigurationsCreateOrUpdateResponse> {
    const poller = await this.beginCreateOrUpdate(
      workspaceName,
      kustoPoolName,
      attachedDatabaseConfigurationName,
      resourceGroupName,
      parameters,
      options
    );
    return poller.pollUntilDone();
  }

  /**
   * Deletes the attached database configuration with the given name.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param attachedDatabaseConfigurationName The name of the attached database configuration.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param options The options parameters.
   */
  async beginDelete(
    workspaceName: string,
    kustoPoolName: string,
    attachedDatabaseConfigurationName: string,
    resourceGroupName: string,
    options?: KustoPoolAttachedDatabaseConfigurationsDeleteOptionalParams
  ): Promise<PollerLike<PollOperationState<void>, void>> {
    const directSendOperation = async (
      args: coreClient.OperationArguments,
      spec: coreClient.OperationSpec
    ): Promise<void> => {
      return this.client.sendOperationRequest(args, spec);
    };
    const sendOperation = async (
      args: coreClient.OperationArguments,
      spec: coreClient.OperationSpec
    ) => {
      let currentRawResponse:
        | coreClient.FullOperationResponse
        | undefined = undefined;
      const providedCallback = args.options?.onResponse;
      const callback: coreClient.RawResponseCallback = (
        rawResponse: coreClient.FullOperationResponse,
        flatResponse: unknown
      ) => {
        currentRawResponse = rawResponse;
        providedCallback?.(rawResponse, flatResponse);
      };
      const updatedArgs = {
        ...args,
        options: {
          ...args.options,
          onResponse: callback
        }
      };
      const flatResponse = await directSendOperation(updatedArgs, spec);
      return {
        flatResponse,
        rawResponse: {
          statusCode: currentRawResponse!.status,
          body: currentRawResponse!.parsedBody,
          headers: currentRawResponse!.headers.toJSON()
        }
      };
    };

    const lro = new LroImpl(
      sendOperation,
      {
        workspaceName,
        kustoPoolName,
        attachedDatabaseConfigurationName,
        resourceGroupName,
        options
      },
      deleteOperationSpec
    );
    return new LroEngine(lro, {
      resumeFrom: options?.resumeFrom,
      intervalInMs: options?.updateIntervalInMs
    });
  }

  /**
   * Deletes the attached database configuration with the given name.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param attachedDatabaseConfigurationName The name of the attached database configuration.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param options The options parameters.
   */
  async beginDeleteAndWait(
    workspaceName: string,
    kustoPoolName: string,
    attachedDatabaseConfigurationName: string,
    resourceGroupName: string,
    options?: KustoPoolAttachedDatabaseConfigurationsDeleteOptionalParams
  ): Promise<void> {
    const poller = await this.beginDelete(
      workspaceName,
      kustoPoolName,
      attachedDatabaseConfigurationName,
      resourceGroupName,
      options
    );
    return poller.pollUntilDone();
  }
}
// Operation Specifications
const serializer = coreClient.createSerializer(Mappers, /* isXml */ false);

const listByKustoPoolOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/workspaces/{workspaceName}/kustoPools/{kustoPoolName}/attachedDatabaseConfigurations",
  httpMethod: "GET",
  responses: {
    200: {
      bodyMapper: Mappers.AttachedDatabaseConfigurationListResult
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  queryParameters: [Parameters.apiVersion1],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.workspaceName,
    Parameters.kustoPoolName1
  ],
  headerParameters: [Parameters.accept],
  serializer
};
const getOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/workspaces/{workspaceName}/kustoPools/{kustoPoolName}/attachedDatabaseConfigurations/{attachedDatabaseConfigurationName}",
  httpMethod: "GET",
  responses: {
    200: {
      bodyMapper: Mappers.AttachedDatabaseConfiguration
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  queryParameters: [Parameters.apiVersion1],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.workspaceName,
    Parameters.kustoPoolName1,
    Parameters.attachedDatabaseConfigurationName
  ],
  headerParameters: [Parameters.accept],
  serializer
};
const createOrUpdateOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/workspaces/{workspaceName}/kustoPools/{kustoPoolName}/attachedDatabaseConfigurations/{attachedDatabaseConfigurationName}",
  httpMethod: "PUT",
  responses: {
    200: {
      bodyMapper: Mappers.AttachedDatabaseConfiguration
    },
    201: {
      bodyMapper: Mappers.AttachedDatabaseConfiguration
    },
    202: {
      bodyMapper: Mappers.AttachedDatabaseConfiguration
    },
    204: {
      bodyMapper: Mappers.AttachedDatabaseConfiguration
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  requestBody: Parameters.parameters24,
  queryParameters: [Parameters.apiVersion1],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.workspaceName,
    Parameters.kustoPoolName1,
    Parameters.attachedDatabaseConfigurationName
  ],
  headerParameters: [Parameters.accept, Parameters.contentType],
  mediaType: "json",
  serializer
};
const deleteOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/workspaces/{workspaceName}/kustoPools/{kustoPoolName}/attachedDatabaseConfigurations/{attachedDatabaseConfigurationName}",
  httpMethod: "DELETE",
  responses: {
    200: {},
    201: {},
    202: {},
    204: {},
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  queryParameters: [Parameters.apiVersion1],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.workspaceName,
    Parameters.kustoPoolName1,
    Parameters.attachedDatabaseConfigurationName
  ],
  headerParameters: [Parameters.accept],
  serializer
};
