/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */

import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { KustoPoolDatabasePrincipalAssignments } from "../operationsInterfaces";
import * as coreClient from "@azure/core-client";
import * as Mappers from "../models/mappers";
import * as Parameters from "../models/parameters";
import { SynapseManagementClient } from "../synapseManagementClient";
import { PollerLike, PollOperationState, LroEngine } from "@azure/core-lro";
import { LroImpl } from "../lroImpl";
import {
  DatabasePrincipalAssignment,
  KustoPoolDatabasePrincipalAssignmentsListOptionalParams,
  DatabasePrincipalAssignmentCheckNameRequest,
  KustoPoolDatabasePrincipalAssignmentsCheckNameAvailabilityOptionalParams,
  KustoPoolDatabasePrincipalAssignmentsCheckNameAvailabilityResponse,
  KustoPoolDatabasePrincipalAssignmentsListResponse,
  KustoPoolDatabasePrincipalAssignmentsGetOptionalParams,
  KustoPoolDatabasePrincipalAssignmentsGetResponse,
  KustoPoolDatabasePrincipalAssignmentsCreateOrUpdateOptionalParams,
  KustoPoolDatabasePrincipalAssignmentsCreateOrUpdateResponse,
  KustoPoolDatabasePrincipalAssignmentsDeleteOptionalParams
} from "../models";

/// <reference lib="esnext.asynciterable" />
/** Class containing KustoPoolDatabasePrincipalAssignments operations. */
export class KustoPoolDatabasePrincipalAssignmentsImpl
  implements KustoPoolDatabasePrincipalAssignments {
  private readonly client: SynapseManagementClient;

  /**
   * Initialize a new instance of the class KustoPoolDatabasePrincipalAssignments class.
   * @param client Reference to the service client
   */
  constructor(client: SynapseManagementClient) {
    this.client = client;
  }

  /**
   * Lists all Kusto pool database principalAssignments.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param databaseName The name of the database in the Kusto pool.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param options The options parameters.
   */
  public list(
    workspaceName: string,
    kustoPoolName: string,
    databaseName: string,
    resourceGroupName: string,
    options?: KustoPoolDatabasePrincipalAssignmentsListOptionalParams
  ): PagedAsyncIterableIterator<DatabasePrincipalAssignment> {
    const iter = this.listPagingAll(
      workspaceName,
      kustoPoolName,
      databaseName,
      resourceGroupName,
      options
    );
    return {
      next() {
        return iter.next();
      },
      [Symbol.asyncIterator]() {
        return this;
      },
      byPage: () => {
        return this.listPagingPage(
          workspaceName,
          kustoPoolName,
          databaseName,
          resourceGroupName,
          options
        );
      }
    };
  }

  private async *listPagingPage(
    workspaceName: string,
    kustoPoolName: string,
    databaseName: string,
    resourceGroupName: string,
    options?: KustoPoolDatabasePrincipalAssignmentsListOptionalParams
  ): AsyncIterableIterator<DatabasePrincipalAssignment[]> {
    let result = await this._list(
      workspaceName,
      kustoPoolName,
      databaseName,
      resourceGroupName,
      options
    );
    yield result.value || [];
  }

  private async *listPagingAll(
    workspaceName: string,
    kustoPoolName: string,
    databaseName: string,
    resourceGroupName: string,
    options?: KustoPoolDatabasePrincipalAssignmentsListOptionalParams
  ): AsyncIterableIterator<DatabasePrincipalAssignment> {
    for await (const page of this.listPagingPage(
      workspaceName,
      kustoPoolName,
      databaseName,
      resourceGroupName,
      options
    )) {
      yield* page;
    }
  }

  /**
   * Checks that the database principal assignment is valid and is not already in use.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param databaseName The name of the database in the Kusto pool.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param principalAssignmentName The name of the resource.
   * @param options The options parameters.
   */
  checkNameAvailability(
    workspaceName: string,
    kustoPoolName: string,
    databaseName: string,
    resourceGroupName: string,
    principalAssignmentName: DatabasePrincipalAssignmentCheckNameRequest,
    options?: KustoPoolDatabasePrincipalAssignmentsCheckNameAvailabilityOptionalParams
  ): Promise<
    KustoPoolDatabasePrincipalAssignmentsCheckNameAvailabilityResponse
  > {
    return this.client.sendOperationRequest(
      {
        workspaceName,
        kustoPoolName,
        databaseName,
        resourceGroupName,
        principalAssignmentName,
        options
      },
      checkNameAvailabilityOperationSpec
    );
  }

  /**
   * Lists all Kusto pool database principalAssignments.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param databaseName The name of the database in the Kusto pool.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param options The options parameters.
   */
  private _list(
    workspaceName: string,
    kustoPoolName: string,
    databaseName: string,
    resourceGroupName: string,
    options?: KustoPoolDatabasePrincipalAssignmentsListOptionalParams
  ): Promise<KustoPoolDatabasePrincipalAssignmentsListResponse> {
    return this.client.sendOperationRequest(
      {
        workspaceName,
        kustoPoolName,
        databaseName,
        resourceGroupName,
        options
      },
      listOperationSpec
    );
  }

  /**
   * Gets a Kusto pool database principalAssignment.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param databaseName The name of the database in the Kusto pool.
   * @param principalAssignmentName The name of the Kusto principalAssignment.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param options The options parameters.
   */
  get(
    workspaceName: string,
    kustoPoolName: string,
    databaseName: string,
    principalAssignmentName: string,
    resourceGroupName: string,
    options?: KustoPoolDatabasePrincipalAssignmentsGetOptionalParams
  ): Promise<KustoPoolDatabasePrincipalAssignmentsGetResponse> {
    return this.client.sendOperationRequest(
      {
        workspaceName,
        kustoPoolName,
        databaseName,
        principalAssignmentName,
        resourceGroupName,
        options
      },
      getOperationSpec
    );
  }

  /**
   * Creates a Kusto pool database principalAssignment.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param databaseName The name of the database in the Kusto pool.
   * @param principalAssignmentName The name of the Kusto principalAssignment.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param parameters The Kusto principalAssignments parameters supplied for the operation.
   * @param options The options parameters.
   */
  async beginCreateOrUpdate(
    workspaceName: string,
    kustoPoolName: string,
    databaseName: string,
    principalAssignmentName: string,
    resourceGroupName: string,
    parameters: DatabasePrincipalAssignment,
    options?: KustoPoolDatabasePrincipalAssignmentsCreateOrUpdateOptionalParams
  ): Promise<
    PollerLike<
      PollOperationState<
        KustoPoolDatabasePrincipalAssignmentsCreateOrUpdateResponse
      >,
      KustoPoolDatabasePrincipalAssignmentsCreateOrUpdateResponse
    >
  > {
    const directSendOperation = async (
      args: coreClient.OperationArguments,
      spec: coreClient.OperationSpec
    ): Promise<KustoPoolDatabasePrincipalAssignmentsCreateOrUpdateResponse> => {
      return this.client.sendOperationRequest(args, spec);
    };
    const sendOperation = async (
      args: coreClient.OperationArguments,
      spec: coreClient.OperationSpec
    ) => {
      let currentRawResponse:
        | coreClient.FullOperationResponse
        | undefined = undefined;
      const providedCallback = args.options?.onResponse;
      const callback: coreClient.RawResponseCallback = (
        rawResponse: coreClient.FullOperationResponse,
        flatResponse: unknown
      ) => {
        currentRawResponse = rawResponse;
        providedCallback?.(rawResponse, flatResponse);
      };
      const updatedArgs = {
        ...args,
        options: {
          ...args.options,
          onResponse: callback
        }
      };
      const flatResponse = await directSendOperation(updatedArgs, spec);
      return {
        flatResponse,
        rawResponse: {
          statusCode: currentRawResponse!.status,
          body: currentRawResponse!.parsedBody,
          headers: currentRawResponse!.headers.toJSON()
        }
      };
    };

    const lro = new LroImpl(
      sendOperation,
      {
        workspaceName,
        kustoPoolName,
        databaseName,
        principalAssignmentName,
        resourceGroupName,
        parameters,
        options
      },
      createOrUpdateOperationSpec
    );
    return new LroEngine(lro, {
      resumeFrom: options?.resumeFrom,
      intervalInMs: options?.updateIntervalInMs
    });
  }

  /**
   * Creates a Kusto pool database principalAssignment.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param databaseName The name of the database in the Kusto pool.
   * @param principalAssignmentName The name of the Kusto principalAssignment.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param parameters The Kusto principalAssignments parameters supplied for the operation.
   * @param options The options parameters.
   */
  async beginCreateOrUpdateAndWait(
    workspaceName: string,
    kustoPoolName: string,
    databaseName: string,
    principalAssignmentName: string,
    resourceGroupName: string,
    parameters: DatabasePrincipalAssignment,
    options?: KustoPoolDatabasePrincipalAssignmentsCreateOrUpdateOptionalParams
  ): Promise<KustoPoolDatabasePrincipalAssignmentsCreateOrUpdateResponse> {
    const poller = await this.beginCreateOrUpdate(
      workspaceName,
      kustoPoolName,
      databaseName,
      principalAssignmentName,
      resourceGroupName,
      parameters,
      options
    );
    return poller.pollUntilDone();
  }

  /**
   * Deletes a Kusto pool principalAssignment.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param databaseName The name of the database in the Kusto pool.
   * @param principalAssignmentName The name of the Kusto principalAssignment.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param options The options parameters.
   */
  async beginDelete(
    workspaceName: string,
    kustoPoolName: string,
    databaseName: string,
    principalAssignmentName: string,
    resourceGroupName: string,
    options?: KustoPoolDatabasePrincipalAssignmentsDeleteOptionalParams
  ): Promise<PollerLike<PollOperationState<void>, void>> {
    const directSendOperation = async (
      args: coreClient.OperationArguments,
      spec: coreClient.OperationSpec
    ): Promise<void> => {
      return this.client.sendOperationRequest(args, spec);
    };
    const sendOperation = async (
      args: coreClient.OperationArguments,
      spec: coreClient.OperationSpec
    ) => {
      let currentRawResponse:
        | coreClient.FullOperationResponse
        | undefined = undefined;
      const providedCallback = args.options?.onResponse;
      const callback: coreClient.RawResponseCallback = (
        rawResponse: coreClient.FullOperationResponse,
        flatResponse: unknown
      ) => {
        currentRawResponse = rawResponse;
        providedCallback?.(rawResponse, flatResponse);
      };
      const updatedArgs = {
        ...args,
        options: {
          ...args.options,
          onResponse: callback
        }
      };
      const flatResponse = await directSendOperation(updatedArgs, spec);
      return {
        flatResponse,
        rawResponse: {
          statusCode: currentRawResponse!.status,
          body: currentRawResponse!.parsedBody,
          headers: currentRawResponse!.headers.toJSON()
        }
      };
    };

    const lro = new LroImpl(
      sendOperation,
      {
        workspaceName,
        kustoPoolName,
        databaseName,
        principalAssignmentName,
        resourceGroupName,
        options
      },
      deleteOperationSpec
    );
    return new LroEngine(lro, {
      resumeFrom: options?.resumeFrom,
      intervalInMs: options?.updateIntervalInMs
    });
  }

  /**
   * Deletes a Kusto pool principalAssignment.
   * @param workspaceName The name of the workspace.
   * @param kustoPoolName The name of the Kusto pool.
   * @param databaseName The name of the database in the Kusto pool.
   * @param principalAssignmentName The name of the Kusto principalAssignment.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param options The options parameters.
   */
  async beginDeleteAndWait(
    workspaceName: string,
    kustoPoolName: string,
    databaseName: string,
    principalAssignmentName: string,
    resourceGroupName: string,
    options?: KustoPoolDatabasePrincipalAssignmentsDeleteOptionalParams
  ): Promise<void> {
    const poller = await this.beginDelete(
      workspaceName,
      kustoPoolName,
      databaseName,
      principalAssignmentName,
      resourceGroupName,
      options
    );
    return poller.pollUntilDone();
  }
}
// Operation Specifications
const serializer = coreClient.createSerializer(Mappers, /* isXml */ false);

const checkNameAvailabilityOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/workspaces/{workspaceName}/kustoPools/{kustoPoolName}/databases/{databaseName}/checkPrincipalAssignmentNameAvailability",
  httpMethod: "POST",
  responses: {
    200: {
      bodyMapper: Mappers.CheckNameResult
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  requestBody: Parameters.principalAssignmentName2,
  queryParameters: [Parameters.apiVersion1],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.workspaceName,
    Parameters.kustoPoolName1,
    Parameters.databaseName
  ],
  headerParameters: [Parameters.accept, Parameters.contentType],
  mediaType: "json",
  serializer
};
const listOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/workspaces/{workspaceName}/kustoPools/{kustoPoolName}/databases/{databaseName}/principalAssignments",
  httpMethod: "GET",
  responses: {
    200: {
      bodyMapper: Mappers.DatabasePrincipalAssignmentListResult
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  queryParameters: [Parameters.apiVersion1],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.workspaceName,
    Parameters.kustoPoolName1,
    Parameters.databaseName
  ],
  headerParameters: [Parameters.accept],
  serializer
};
const getOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/workspaces/{workspaceName}/kustoPools/{kustoPoolName}/databases/{databaseName}/principalAssignments/{principalAssignmentName}",
  httpMethod: "GET",
  responses: {
    200: {
      bodyMapper: Mappers.DatabasePrincipalAssignment
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  queryParameters: [Parameters.apiVersion1],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.workspaceName,
    Parameters.kustoPoolName1,
    Parameters.databaseName,
    Parameters.principalAssignmentName1
  ],
  headerParameters: [Parameters.accept],
  serializer
};
const createOrUpdateOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/workspaces/{workspaceName}/kustoPools/{kustoPoolName}/databases/{databaseName}/principalAssignments/{principalAssignmentName}",
  httpMethod: "PUT",
  responses: {
    200: {
      bodyMapper: Mappers.DatabasePrincipalAssignment
    },
    201: {
      bodyMapper: Mappers.DatabasePrincipalAssignment
    },
    202: {
      bodyMapper: Mappers.DatabasePrincipalAssignment
    },
    204: {
      bodyMapper: Mappers.DatabasePrincipalAssignment
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  requestBody: Parameters.parameters29,
  queryParameters: [Parameters.apiVersion1],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.workspaceName,
    Parameters.kustoPoolName1,
    Parameters.databaseName,
    Parameters.principalAssignmentName1
  ],
  headerParameters: [Parameters.accept, Parameters.contentType],
  mediaType: "json",
  serializer
};
const deleteOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/workspaces/{workspaceName}/kustoPools/{kustoPoolName}/databases/{databaseName}/principalAssignments/{principalAssignmentName}",
  httpMethod: "DELETE",
  responses: {
    200: {},
    201: {},
    202: {},
    204: {},
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  queryParameters: [Parameters.apiVersion1],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.workspaceName,
    Parameters.kustoPoolName1,
    Parameters.databaseName,
    Parameters.principalAssignmentName1
  ],
  headerParameters: [Parameters.accept],
  serializer
};
