/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */

import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { PrivateEndpointConnectionsPrivateLinkHub } from "../operationsInterfaces";
import * as coreClient from "@azure/core-client";
import * as Mappers from "../models/mappers";
import * as Parameters from "../models/parameters";
import { SynapseManagementClient } from "../synapseManagementClient";
import {
  PrivateEndpointConnectionForPrivateLinkHub,
  PrivateEndpointConnectionsPrivateLinkHubListNextOptionalParams,
  PrivateEndpointConnectionsPrivateLinkHubListOptionalParams,
  PrivateEndpointConnectionsPrivateLinkHubListResponse,
  PrivateEndpointConnectionsPrivateLinkHubGetOptionalParams,
  PrivateEndpointConnectionsPrivateLinkHubGetResponse,
  PrivateEndpointConnectionsPrivateLinkHubListNextResponse
} from "../models";

/// <reference lib="esnext.asynciterable" />
/** Class containing PrivateEndpointConnectionsPrivateLinkHub operations. */
export class PrivateEndpointConnectionsPrivateLinkHubImpl
  implements PrivateEndpointConnectionsPrivateLinkHub {
  private readonly client: SynapseManagementClient;

  /**
   * Initialize a new instance of the class PrivateEndpointConnectionsPrivateLinkHub class.
   * @param client Reference to the service client
   */
  constructor(client: SynapseManagementClient) {
    this.client = client;
  }

  /**
   * Get all PrivateEndpointConnections in the PrivateLinkHub
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param privateLinkHubName Name of the privateLinkHub
   * @param options The options parameters.
   */
  public list(
    resourceGroupName: string,
    privateLinkHubName: string,
    options?: PrivateEndpointConnectionsPrivateLinkHubListOptionalParams
  ): PagedAsyncIterableIterator<PrivateEndpointConnectionForPrivateLinkHub> {
    const iter = this.listPagingAll(
      resourceGroupName,
      privateLinkHubName,
      options
    );
    return {
      next() {
        return iter.next();
      },
      [Symbol.asyncIterator]() {
        return this;
      },
      byPage: () => {
        return this.listPagingPage(
          resourceGroupName,
          privateLinkHubName,
          options
        );
      }
    };
  }

  private async *listPagingPage(
    resourceGroupName: string,
    privateLinkHubName: string,
    options?: PrivateEndpointConnectionsPrivateLinkHubListOptionalParams
  ): AsyncIterableIterator<PrivateEndpointConnectionForPrivateLinkHub[]> {
    let result = await this._list(
      resourceGroupName,
      privateLinkHubName,
      options
    );
    yield result.value || [];
    let continuationToken = result.nextLink;
    while (continuationToken) {
      result = await this._listNext(
        resourceGroupName,
        privateLinkHubName,
        continuationToken,
        options
      );
      continuationToken = result.nextLink;
      yield result.value || [];
    }
  }

  private async *listPagingAll(
    resourceGroupName: string,
    privateLinkHubName: string,
    options?: PrivateEndpointConnectionsPrivateLinkHubListOptionalParams
  ): AsyncIterableIterator<PrivateEndpointConnectionForPrivateLinkHub> {
    for await (const page of this.listPagingPage(
      resourceGroupName,
      privateLinkHubName,
      options
    )) {
      yield* page;
    }
  }

  /**
   * Get all PrivateEndpointConnections in the PrivateLinkHub
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param privateLinkHubName Name of the privateLinkHub
   * @param options The options parameters.
   */
  private _list(
    resourceGroupName: string,
    privateLinkHubName: string,
    options?: PrivateEndpointConnectionsPrivateLinkHubListOptionalParams
  ): Promise<PrivateEndpointConnectionsPrivateLinkHubListResponse> {
    return this.client.sendOperationRequest(
      { resourceGroupName, privateLinkHubName, options },
      listOperationSpec
    );
  }

  /**
   * Get all PrivateEndpointConnection in the PrivateLinkHub by name
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param privateLinkHubName Name of the privateLinkHub
   * @param privateEndpointConnectionName Name of the privateEndpointConnection
   * @param options The options parameters.
   */
  get(
    resourceGroupName: string,
    privateLinkHubName: string,
    privateEndpointConnectionName: string,
    options?: PrivateEndpointConnectionsPrivateLinkHubGetOptionalParams
  ): Promise<PrivateEndpointConnectionsPrivateLinkHubGetResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        privateLinkHubName,
        privateEndpointConnectionName,
        options
      },
      getOperationSpec
    );
  }

  /**
   * ListNext
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param privateLinkHubName Name of the privateLinkHub
   * @param nextLink The nextLink from the previous successful call to the List method.
   * @param options The options parameters.
   */
  private _listNext(
    resourceGroupName: string,
    privateLinkHubName: string,
    nextLink: string,
    options?: PrivateEndpointConnectionsPrivateLinkHubListNextOptionalParams
  ): Promise<PrivateEndpointConnectionsPrivateLinkHubListNextResponse> {
    return this.client.sendOperationRequest(
      { resourceGroupName, privateLinkHubName, nextLink, options },
      listNextOperationSpec
    );
  }
}
// Operation Specifications
const serializer = coreClient.createSerializer(Mappers, /* isXml */ false);

const listOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/privateLinkHubs/{privateLinkHubName}/privateEndpointConnections",
  httpMethod: "GET",
  responses: {
    200: {
      bodyMapper:
        Mappers.PrivateEndpointConnectionForPrivateLinkHubResourceCollectionResponse
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  queryParameters: [Parameters.apiVersion],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.privateLinkHubName
  ],
  headerParameters: [Parameters.accept],
  serializer
};
const getOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/privateLinkHubs/{privateLinkHubName}/privateEndpointConnections/{privateEndpointConnectionName}",
  httpMethod: "GET",
  responses: {
    200: {
      bodyMapper: Mappers.PrivateEndpointConnectionForPrivateLinkHub
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  queryParameters: [Parameters.apiVersion],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.privateEndpointConnectionName,
    Parameters.privateLinkHubName
  ],
  headerParameters: [Parameters.accept],
  serializer
};
const listNextOperationSpec: coreClient.OperationSpec = {
  path: "{nextLink}",
  httpMethod: "GET",
  responses: {
    200: {
      bodyMapper:
        Mappers.PrivateEndpointConnectionForPrivateLinkHubResourceCollectionResponse
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  queryParameters: [Parameters.apiVersion],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.nextLink,
    Parameters.privateLinkHubName
  ],
  headerParameters: [Parameters.accept],
  serializer
};
