/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */

import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { PrivateLinkHubPrivateLinkResources } from "../operationsInterfaces";
import * as coreClient from "@azure/core-client";
import * as Mappers from "../models/mappers";
import * as Parameters from "../models/parameters";
import { SynapseManagementClient } from "../synapseManagementClient";
import {
  PrivateLinkResource,
  PrivateLinkHubPrivateLinkResourcesListNextOptionalParams,
  PrivateLinkHubPrivateLinkResourcesListOptionalParams,
  PrivateLinkHubPrivateLinkResourcesListResponse,
  PrivateLinkHubPrivateLinkResourcesGetOptionalParams,
  PrivateLinkHubPrivateLinkResourcesGetResponse,
  PrivateLinkHubPrivateLinkResourcesListNextResponse
} from "../models";

/// <reference lib="esnext.asynciterable" />
/** Class containing PrivateLinkHubPrivateLinkResources operations. */
export class PrivateLinkHubPrivateLinkResourcesImpl
  implements PrivateLinkHubPrivateLinkResources {
  private readonly client: SynapseManagementClient;

  /**
   * Initialize a new instance of the class PrivateLinkHubPrivateLinkResources class.
   * @param client Reference to the service client
   */
  constructor(client: SynapseManagementClient) {
    this.client = client;
  }

  /**
   * Get all private link resources for a private link hub
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param privateLinkHubName The name of the private link hub
   * @param options The options parameters.
   */
  public list(
    resourceGroupName: string,
    privateLinkHubName: string,
    options?: PrivateLinkHubPrivateLinkResourcesListOptionalParams
  ): PagedAsyncIterableIterator<PrivateLinkResource> {
    const iter = this.listPagingAll(
      resourceGroupName,
      privateLinkHubName,
      options
    );
    return {
      next() {
        return iter.next();
      },
      [Symbol.asyncIterator]() {
        return this;
      },
      byPage: () => {
        return this.listPagingPage(
          resourceGroupName,
          privateLinkHubName,
          options
        );
      }
    };
  }

  private async *listPagingPage(
    resourceGroupName: string,
    privateLinkHubName: string,
    options?: PrivateLinkHubPrivateLinkResourcesListOptionalParams
  ): AsyncIterableIterator<PrivateLinkResource[]> {
    let result = await this._list(
      resourceGroupName,
      privateLinkHubName,
      options
    );
    yield result.value || [];
    let continuationToken = result.nextLink;
    while (continuationToken) {
      result = await this._listNext(
        resourceGroupName,
        privateLinkHubName,
        continuationToken,
        options
      );
      continuationToken = result.nextLink;
      yield result.value || [];
    }
  }

  private async *listPagingAll(
    resourceGroupName: string,
    privateLinkHubName: string,
    options?: PrivateLinkHubPrivateLinkResourcesListOptionalParams
  ): AsyncIterableIterator<PrivateLinkResource> {
    for await (const page of this.listPagingPage(
      resourceGroupName,
      privateLinkHubName,
      options
    )) {
      yield* page;
    }
  }

  /**
   * Get all private link resources for a private link hub
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param privateLinkHubName The name of the private link hub
   * @param options The options parameters.
   */
  private _list(
    resourceGroupName: string,
    privateLinkHubName: string,
    options?: PrivateLinkHubPrivateLinkResourcesListOptionalParams
  ): Promise<PrivateLinkHubPrivateLinkResourcesListResponse> {
    return this.client.sendOperationRequest(
      { resourceGroupName, privateLinkHubName, options },
      listOperationSpec
    );
  }

  /**
   * Get private link resource in private link hub
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param privateLinkHubName The name of the private link hub
   * @param privateLinkResourceName The name of the private link resource
   * @param options The options parameters.
   */
  get(
    resourceGroupName: string,
    privateLinkHubName: string,
    privateLinkResourceName: string,
    options?: PrivateLinkHubPrivateLinkResourcesGetOptionalParams
  ): Promise<PrivateLinkHubPrivateLinkResourcesGetResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        privateLinkHubName,
        privateLinkResourceName,
        options
      },
      getOperationSpec
    );
  }

  /**
   * ListNext
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param privateLinkHubName The name of the private link hub
   * @param nextLink The nextLink from the previous successful call to the List method.
   * @param options The options parameters.
   */
  private _listNext(
    resourceGroupName: string,
    privateLinkHubName: string,
    nextLink: string,
    options?: PrivateLinkHubPrivateLinkResourcesListNextOptionalParams
  ): Promise<PrivateLinkHubPrivateLinkResourcesListNextResponse> {
    return this.client.sendOperationRequest(
      { resourceGroupName, privateLinkHubName, nextLink, options },
      listNextOperationSpec
    );
  }
}
// Operation Specifications
const serializer = coreClient.createSerializer(Mappers, /* isXml */ false);

const listOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/privateLinkHubs/{privateLinkHubName}/privateLinkResources",
  httpMethod: "GET",
  responses: {
    200: {
      bodyMapper: Mappers.PrivateLinkResourceListResult
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  queryParameters: [Parameters.apiVersion],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.privateLinkHubName
  ],
  headerParameters: [Parameters.accept],
  serializer
};
const getOperationSpec: coreClient.OperationSpec = {
  path:
    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Synapse/privateLinkHubs/{privateLinkHubName}/privateLinkResources/{privateLinkResourceName}",
  httpMethod: "GET",
  responses: {
    200: {
      bodyMapper: Mappers.PrivateLinkResource
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  queryParameters: [Parameters.apiVersion],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.privateLinkResourceName,
    Parameters.privateLinkHubName
  ],
  headerParameters: [Parameters.accept],
  serializer
};
const listNextOperationSpec: coreClient.OperationSpec = {
  path: "{nextLink}",
  httpMethod: "GET",
  responses: {
    200: {
      bodyMapper: Mappers.PrivateLinkResourceListResult
    },
    default: {
      bodyMapper: Mappers.ErrorResponse
    }
  },
  queryParameters: [Parameters.apiVersion],
  urlParameters: [
    Parameters.$host,
    Parameters.subscriptionId,
    Parameters.resourceGroupName,
    Parameters.nextLink,
    Parameters.privateLinkHubName
  ],
  headerParameters: [Parameters.accept],
  serializer
};
