/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */

import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { PollerLike, PollOperationState } from "@azure/core-lro";
import {
  EncryptionProtector,
  WorkspaceManagedSqlServerEncryptionProtectorListOptionalParams,
  EncryptionProtectorName,
  WorkspaceManagedSqlServerEncryptionProtectorGetOptionalParams,
  WorkspaceManagedSqlServerEncryptionProtectorGetResponse,
  WorkspaceManagedSqlServerEncryptionProtectorCreateOrUpdateOptionalParams,
  WorkspaceManagedSqlServerEncryptionProtectorCreateOrUpdateResponse,
  WorkspaceManagedSqlServerEncryptionProtectorRevalidateOptionalParams
} from "../models";

/// <reference lib="esnext.asynciterable" />
/** Interface representing a WorkspaceManagedSqlServerEncryptionProtector. */
export interface WorkspaceManagedSqlServerEncryptionProtector {
  /**
   * Get list of encryption protectors for workspace managed sql server.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param workspaceName The name of the workspace.
   * @param options The options parameters.
   */
  list(
    resourceGroupName: string,
    workspaceName: string,
    options?: WorkspaceManagedSqlServerEncryptionProtectorListOptionalParams
  ): PagedAsyncIterableIterator<EncryptionProtector>;
  /**
   * Get workspace managed sql server's encryption protector.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param workspaceName The name of the workspace.
   * @param encryptionProtectorName The name of the encryption protector.
   * @param options The options parameters.
   */
  get(
    resourceGroupName: string,
    workspaceName: string,
    encryptionProtectorName: EncryptionProtectorName,
    options?: WorkspaceManagedSqlServerEncryptionProtectorGetOptionalParams
  ): Promise<WorkspaceManagedSqlServerEncryptionProtectorGetResponse>;
  /**
   * Updates workspace managed sql server's encryption protector.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param workspaceName The name of the workspace.
   * @param encryptionProtectorName The name of the encryption protector.
   * @param parameters The requested encryption protector resource state.
   * @param options The options parameters.
   */
  beginCreateOrUpdate(
    resourceGroupName: string,
    workspaceName: string,
    encryptionProtectorName: EncryptionProtectorName,
    parameters: EncryptionProtector,
    options?: WorkspaceManagedSqlServerEncryptionProtectorCreateOrUpdateOptionalParams
  ): Promise<
    PollerLike<
      PollOperationState<
        WorkspaceManagedSqlServerEncryptionProtectorCreateOrUpdateResponse
      >,
      WorkspaceManagedSqlServerEncryptionProtectorCreateOrUpdateResponse
    >
  >;
  /**
   * Updates workspace managed sql server's encryption protector.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param workspaceName The name of the workspace.
   * @param encryptionProtectorName The name of the encryption protector.
   * @param parameters The requested encryption protector resource state.
   * @param options The options parameters.
   */
  beginCreateOrUpdateAndWait(
    resourceGroupName: string,
    workspaceName: string,
    encryptionProtectorName: EncryptionProtectorName,
    parameters: EncryptionProtector,
    options?: WorkspaceManagedSqlServerEncryptionProtectorCreateOrUpdateOptionalParams
  ): Promise<
    WorkspaceManagedSqlServerEncryptionProtectorCreateOrUpdateResponse
  >;
  /**
   * Revalidates workspace managed sql server's existing encryption protector.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param workspaceName The name of the workspace.
   * @param encryptionProtectorName The name of the encryption protector.
   * @param options The options parameters.
   */
  beginRevalidate(
    resourceGroupName: string,
    workspaceName: string,
    encryptionProtectorName: EncryptionProtectorName,
    options?: WorkspaceManagedSqlServerEncryptionProtectorRevalidateOptionalParams
  ): Promise<PollerLike<PollOperationState<void>, void>>;
  /**
   * Revalidates workspace managed sql server's existing encryption protector.
   * @param resourceGroupName The name of the resource group. The name is case insensitive.
   * @param workspaceName The name of the workspace.
   * @param encryptionProtectorName The name of the encryption protector.
   * @param options The options parameters.
   */
  beginRevalidateAndWait(
    resourceGroupName: string,
    workspaceName: string,
    encryptionProtectorName: EncryptionProtectorName,
    options?: WorkspaceManagedSqlServerEncryptionProtectorRevalidateOptionalParams
  ): Promise<void>;
}
