import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { WorkspaceManagedSqlServerVulnerabilityAssessments } from "../operationsInterfaces";
import { SynapseManagementClient } from "../synapseManagementClient";
import { ServerVulnerabilityAssessment, WorkspaceManagedSqlServerVulnerabilityAssessmentsListOptionalParams, VulnerabilityAssessmentName, WorkspaceManagedSqlServerVulnerabilityAssessmentsGetOptionalParams, WorkspaceManagedSqlServerVulnerabilityAssessmentsGetResponse, WorkspaceManagedSqlServerVulnerabilityAssessmentsCreateOrUpdateOptionalParams, WorkspaceManagedSqlServerVulnerabilityAssessmentsCreateOrUpdateResponse, WorkspaceManagedSqlServerVulnerabilityAssessmentsDeleteOptionalParams } from "../models";
/** Class containing WorkspaceManagedSqlServerVulnerabilityAssessments operations. */
export declare class WorkspaceManagedSqlServerVulnerabilityAssessmentsImpl implements WorkspaceManagedSqlServerVulnerabilityAssessments {
    private readonly client;
    /**
     * Initialize a new instance of the class WorkspaceManagedSqlServerVulnerabilityAssessments class.
     * @param client Reference to the service client
     */
    constructor(client: SynapseManagementClient);
    /**
     * Lists the vulnerability assessment policies associated with a workspace managed sql server.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param options The options parameters.
     */
    list(resourceGroupName: string, workspaceName: string, options?: WorkspaceManagedSqlServerVulnerabilityAssessmentsListOptionalParams): PagedAsyncIterableIterator<ServerVulnerabilityAssessment>;
    private listPagingPage;
    private listPagingAll;
    /**
     * Get workspace managed sql server's vulnerability assessment.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param vulnerabilityAssessmentName The name of the vulnerability assessment.
     * @param options The options parameters.
     */
    get(resourceGroupName: string, workspaceName: string, vulnerabilityAssessmentName: VulnerabilityAssessmentName, options?: WorkspaceManagedSqlServerVulnerabilityAssessmentsGetOptionalParams): Promise<WorkspaceManagedSqlServerVulnerabilityAssessmentsGetResponse>;
    /**
     * Create or Update workspace managed sql server's vulnerability assessment.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param vulnerabilityAssessmentName The name of the vulnerability assessment.
     * @param parameters Properties for vulnerability assessment.
     * @param options The options parameters.
     */
    createOrUpdate(resourceGroupName: string, workspaceName: string, vulnerabilityAssessmentName: VulnerabilityAssessmentName, parameters: ServerVulnerabilityAssessment, options?: WorkspaceManagedSqlServerVulnerabilityAssessmentsCreateOrUpdateOptionalParams): Promise<WorkspaceManagedSqlServerVulnerabilityAssessmentsCreateOrUpdateResponse>;
    /**
     * Remove workspace managed sql server's vulnerability assessment.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param vulnerabilityAssessmentName The name of the vulnerability assessment.
     * @param options The options parameters.
     */
    delete(resourceGroupName: string, workspaceName: string, vulnerabilityAssessmentName: VulnerabilityAssessmentName, options?: WorkspaceManagedSqlServerVulnerabilityAssessmentsDeleteOptionalParams): Promise<void>;
    /**
     * Lists the vulnerability assessment policies associated with a workspace managed sql server.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param options The options parameters.
     */
    private _list;
    /**
     * ListNext
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param workspaceName The name of the workspace.
     * @param nextLink The nextLink from the previous successful call to the List method.
     * @param options The options parameters.
     */
    private _listNext;
}
//# sourceMappingURL=workspaceManagedSqlServerVulnerabilityAssessments.d.ts.map